from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .ScoreboardsHelper import ScoreboardsHelper
from .NBTElementHelper_NBTCompoundHelper import NBTElementHelper_NBTCompoundHelper
from .ItemEntityHelper import ItemEntityHelper
from .BaseHelper import BaseHelper
from .SuggestionsBuilderHelper import SuggestionsBuilderHelper
from .BlockDataHelper import BlockDataHelper
from .ServerInfoHelper import ServerInfoHelper
from .TextHelper import TextHelper
from .ItemStackHelper import ItemStackHelper
from .CommandNodeHelper import CommandNodeHelper
from .ChatHudLineHelper import ChatHudLineHelper
from .ScoreboardObjectiveHelper import ScoreboardObjectiveHelper
from .TextFieldWidgetHelper import TextFieldWidgetHelper
from .BlockPosHelper import BlockPosHelper
from .TeamHelper import TeamHelper
from .PlayerEntityHelper import PlayerEntityHelper
from .VillagerEntityHelper import VillagerEntityHelper
from .StyleHelper import StyleHelper
from .BlockStateHelper import BlockStateHelper
from .StatusEffectHelper import StatusEffectHelper
from .LivingEntityHelper import LivingEntityHelper
from .EntityHelper import EntityHelper
from .NBTElementHelper_NBTNumberHelper import NBTElementHelper_NBTNumberHelper
from .ButtonWidgetHelper import ButtonWidgetHelper
from .OptionsHelper import OptionsHelper
from .RecipeHelper import RecipeHelper
from .MerchantEntityHelper import MerchantEntityHelper
from .ClientPlayerEntityHelper import ClientPlayerEntityHelper
from .TradeOfferHelper import TradeOfferHelper
from .BossBarHelper import BossBarHelper
from .NBTElementHelper_NBTListHelper import NBTElementHelper_NBTListHelper
from .PlayerListEntryHelper import PlayerListEntryHelper
from .PlayerAbilitiesHelper import PlayerAbilitiesHelper
from .NBTElementHelper import NBTElementHelper
from .BlockHelper import BlockHelper

File = TypeVar["java.io.File"]




from typing import overload
from typing import TypeVar
from .MacroScreen import MacroScreen
from .MultiElementContainer import MultiElementContainer

Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]

class ServiceScreen(MacroScreen):

	@overload
	def __init__(self, parent: Screen) -> None:
		pass

	@overload
	def addService(self, service: str) -> None:
		pass

	@overload
	def removeMacro(self, macro: MultiElementContainer) -> None:
		pass

	@overload
	def setFile(self, macro: MultiElementContainer) -> None:
		pass

	@overload
	def close(self) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .IPalettedContainerData import IPalettedContainerData

PalettedContainer_PaletteProvider = TypeVar["net.minecraft.world.chunk.PalettedContainer.PaletteProvider"]

class IPalettedContainer:

	@overload
	def jsmacros_getData(self) -> IPalettedContainerData:
		pass

	@overload
	def jsmacros_getPaletteProvider(self) -> PalettedContainer_PaletteProvider:
		pass

	pass





from typing import overload
from typing import TypeVar

SlotActionType = TypeVar["net.minecraft.screen.slot.SlotActionType"]
CallbackInfo = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfo"]
Slot = TypeVar["net.minecraft.screen.slot.Slot"]

class MixinCreativeInventoryScreen:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def beforeMouseClick(self, slot: Slot, slotId: int, button: int, actionType: SlotActionType, ci: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper

CommandNode = TypeVar["com.mojang.brigadier.tree.CommandNode"]

class CommandNodeHelper(BaseHelper):
	fabric: CommandNode

	@overload
	def __init__(self, base: CommandNode, fabric: CommandNode) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

Prism4j_Grammar = TypeVar["io.noties.prism4j.Prism4j.Grammar"]

class Prism_regex:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def create(self, prism4j: Prism4j) -> Prism4j_Grammar:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper
from .ItemStackHelper import ItemStackHelper

Recipe = TypeVar["net.minecraft.recipe.Recipe__"]

class RecipeHelper(BaseHelper):
	"""
	Since: 1.3.1 
	"""

	@overload
	def __init__(self, base: Recipe, syncId: int) -> None:
		pass

	@overload
	def getId(self) -> str:
		"""
		Since: 1.3.1 
		"""
		pass

	@overload
	def getOutput(self) -> ItemStackHelper:
		"""
		Since: 1.3.1 
		"""
		pass

	@overload
	def craft(self, craftAll: bool) -> None:
		"""
		Since: 1.3.1 

		Args:
			craftAll: 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .OverlayContainer import OverlayContainer
from .IOverlayParent import IOverlayParent

Consumer = TypeVar["java.util.function.Consumer_java.lang.String_"]
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]

class EventChooser(OverlayContainer):

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, selected: str, parent: IOverlayParent, setEvent: Consumer) -> None:
		pass

	@overload
	def selectEvent(self, event: str) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def addEvent(self, eventName: str) -> None:
		pass

	@overload
	def updateEventPos(self) -> None:
		pass

	@overload
	def onScrollbar(self, page: float) -> None:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .IClientPlayerEntity import IClientPlayerEntity

GameProfile = TypeVar["com.mojang.authlib.GameProfile"]
AbstractClientPlayerEntity = TypeVar["net.minecraft.client.network.AbstractClientPlayerEntity"]
ClientWorld = TypeVar["net.minecraft.client.world.ClientWorld"]

class MixinClientPlayerEntity(IClientPlayerEntity, AbstractClientPlayerEntity):

	@overload
	def __init__(self, world: ClientWorld, profile: GameProfile, publicKey: PlayerPublicKey) -> None:
		pass

	@overload
	def jsmacros_sendChatMessageBypass(self, message: str) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper

PlayerListEntry = TypeVar["net.minecraft.client.network.PlayerListEntry"]

class PlayerListEntryHelper(BaseHelper):
	"""
	Since: 1.0.2 
	"""

	@overload
	def __init__(self, p: PlayerListEntry) -> None:
		pass

	@overload
	def getUUID(self) -> str:
		"""
		Since: 1.1.9 
		"""
		pass

	@overload
	def getName(self) -> str:
		"""
		Since: 1.0.2 
		"""
		pass

	@overload
	def getPing(self) -> int:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getGamemode(self) -> str:
		"""
		Since: 1.6.5 

		Returns:
			null if unknown 
		"""
		pass

	@overload
	def getDisplayText(self) -> TextHelper:
		"""
		Since: 1.1.9 
		"""
		pass

	@overload
	def getPublicKey(self) -> List[float]:
		"""
		Since: 1.8.2 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .RenderCommon_RenderElement import RenderCommon_RenderElement

MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]

class RenderCommon_Rect(RenderCommon_RenderElement):
	"""
	Since: 1.0.5 
	"""
	rotation: float
	x1: int
	y1: int
	x2: int
	y2: int
	color: int
	zIndex: int

	@overload
	def __init__(self, x1: int, y1: int, x2: int, y2: int, color: int, rotation: float, zIndex: int) -> None:
		pass

	@overload
	def __init__(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float, zIndex: int) -> None:
		pass

	@overload
	def setColor(self, color: int) -> "RenderCommon_Rect":
		"""
		Since: 1.0.5 

		Args:
			color: 
		"""
		pass

	@overload
	def setColor(self, color: int, alpha: int) -> "RenderCommon_Rect":
		"""
		Since: 1.1.8 

		Args:
			color: 
			alpha: 
		"""
		pass

	@overload
	def setAlpha(self, alpha: int) -> "RenderCommon_Rect":
		"""
		Since: 1.1.8 

		Args:
			alpha: 
		"""
		pass

	@overload
	def setPos(self, x1: int, y1: int, x2: int, y2: int) -> "RenderCommon_Rect":
		"""
		Since: 1.1.8 

		Args:
			y1: 
			x1: 
			y2: 
			x2: 
		"""
		pass

	@overload
	def setRotation(self, rotation: float) -> "RenderCommon_Rect":
		"""
		Since: 1.2.6 

		Args:
			rotation: 
		"""
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def getZIndex(self) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar

CallbackInfo = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfo"]
SoundInstance = TypeVar["net.minecraft.client.sound.SoundInstance"]

class MixinSoundSystem:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onPlay(self, instance: SoundInstance, info: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .MacroScreen import MacroScreen

Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]

class EventMacrosScreen(MacroScreen):

	@overload
	def __init__(self, parent: Screen) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .PerExecLibrary import PerExecLibrary
from .FReflection_CombinedVariableClassLoader import FReflection_CombinedVariableClassLoader
from .BaseScriptContext import BaseScriptContext
from .ProxyBuilder import ProxyBuilder
from .ClassBuilder import ClassBuilder
from .LibraryBuilder import LibraryBuilder
from .Mappings import Mappings
from .WrappedClassInstance import WrappedClassInstance

Field = TypeVar["java.lang.reflect.Field"]
T = TypeVar("T")
Method = TypeVar["java.lang.reflect.Method"]

class FReflection(PerExecLibrary):
	"""Functions for getting and using raw java classes, methods and functions.

An instance of this class is passed to scripts as the 'Reflection' variable.\n
	Since: 1.2.3 
	"""
	classLoader: FReflection_CombinedVariableClassLoader

	@overload
	def __init__(self, context: BaseScriptContext) -> None:
		pass

	@overload
	def getClass(self, name: str) -> Class:
		"""
		Since: 1.2.3 

		Args:
			name: name of class like 'path.to.class' 

		Returns:
			resolved class 
		"""
		pass

	@overload
	def getClass(self, name: str, name2: str) -> Class:
		"""Use this to specify a class with intermediary and yarn names of classes for cleaner code. also has support for
java primitives by using their name in lower case.\n
		Since: 1.2.3 

		Args:
			name: first try 
			name2: second try 

		Returns:
			a Class reference. 
		"""
		pass

	@overload
	def getDeclaredMethod(self, c: Class, name: str, parameterTypes: List[Class]) -> Method:
		"""
		Since: 1.2.3 

		Args:
			c: 
			parameterTypes: 
			name: 
		"""
		pass

	@overload
	def getDeclaredMethod(self, c: Class, name: str, name2: str, parameterTypes: List[Class]) -> Method:
		"""Use this to specify a method with intermediary and yarn names of classes for cleaner code.\n
		Since: 1.2.3 

		Args:
			c: 
			parameterTypes: 
			name: 
			name2: 

		Returns:
			a Method reference. 
		"""
		pass

	@overload
	def getMethod(self, c: Class, name: str, name2: str, parameterTypes: List[Class]) -> Method:
		"""
		Since: 1.6.0 

		Args:
			c: 
			parameterTypes: 
			name: 
			name2: 
		"""
		pass

	@overload
	def getMethod(self, c: Class, name: str, parameterTypes: List[Class]) -> Method:
		"""
		Since: 1.6.0 

		Args:
			c: 
			parameterTypes: 
			name: 
		"""
		pass

	@overload
	def getDeclaredField(self, c: Class, name: str) -> Field:
		"""
		Since: 1.2.3 

		Args:
			c: 
			name: 
		"""
		pass

	@overload
	def getDeclaredField(self, c: Class, name: str, name2: str) -> Field:
		"""Use this to specify a field with intermediary and yarn names of classes for cleaner code.\n
		Since: 1.2.3 

		Args:
			c: 
			name: 
			name2: 

		Returns:
			a Field reference. 
		"""
		pass

	@overload
	def getField(self, c: Class, name: str) -> Field:
		"""
		Since: 1.6.0 

		Args:
			c: 
			name: 
		"""
		pass

	@overload
	def getField(self, c: Class, name: str, name2: str) -> Field:
		"""
		Since: 1.6.0 

		Args:
			c: 
			name: 
			name2: 
		"""
		pass

	@overload
	def invokeMethod(self, m: Method, c: object, objects: List[object]) -> object:
		"""Invoke a method on an object with auto type coercion for numbers.\n
		Since: 1.2.3 

		Args:
			c: object (can be 'null' for statics) 
			objects: 
			m: method 
		"""
		pass

	@overload
	def newInstance(self, c: Class, objects: List[object]) -> T:
		"""Attempts to create a new instance of a class. You probably don't have to use this one and can just call '
new' on a Class unless you're in LUA, but then you also have the (kinda poorly
doccumented, can someone find a better docs link for me) LuaJava Library .\n
		Since: 1.2.7 

		Args:
			c: 
			objects: 
		"""
		pass

	@overload
	def createClassProxyBuilder(self, clazz: Class, interfaces: List[Class]) -> ProxyBuilder:
		"""proxy for extending java classes in the guest language with proper threading support.\n
		Since: 1.6.0 

		Args:
			interfaces: 
			T: 
			clazz: 
		"""
		pass

	@overload
	def createClassBuilder(self, cName: str, clazz: Class, interfaces: List[Class]) -> ClassBuilder:
		"""
		Since: 1.6.5 

		Args:
			interfaces: 
			T: 
			cName: 
			clazz: 
		"""
		pass

	@overload
	def getClassFromClassBuilderResult(self, cName: str) -> Class:
		"""
		Since: 1.6.5 

		Args:
			cName: 
		"""
		pass

	@overload
	def createLibraryBuilder(self, name: str, perExec: bool, acceptedLangs: List[str]) -> LibraryBuilder:
		pass

	@overload
	def loadJarFile(self, file: str) -> bool:
		"""Loads a jar file to be accessible with this library.\n
		Since: 1.2.6 

		Args:
			file: relative to the script's folder. 

		Returns:
			success value 
		"""
		pass

	@overload
	def loadCurrentMappingHelper(self) -> Mappings:
		"""
		Since: 1.3.1 

		Returns:
			the previous mapping helper generated with FReflection#loadMappingHelper(java.lang.String) 
		"""
		pass

	@overload
	def getClassName(self, o: object) -> str:
		"""
		Since: 1.3.1 

		Args:
			o: class you want the name of 

		Returns:
			the fully qualified class name (with "."'s not "/"'s) 
		"""
		pass

	@overload
	def loadMappingHelper(self, urlorfile: str) -> Mappings:
		"""
		Since: 1.3.1 

		Args:
			urlorfile: a url or file path the the yarn mappings '-v2.jar' file, or '.tiny' file. for example 'https://maven.fabricmc.net/net/fabricmc/yarn/1.16.5%2Bbuild.3/yarn-1.16.5%2Bbuild.3-v2.jar' , if same url/path as previous this will load from cache. 

		Returns:
			the associated mapping helper. 
		"""
		pass

	@overload
	def wrapInstace(self, instance: T) -> WrappedClassInstance:
		"""
		Since: 1.6.5 

		Args:
			instance: 
			T: 
		"""
		pass

	@overload
	def getWrappedClass(self, className: str) -> WrappedClassInstance:
		"""
		Since: 1.6.5 

		Args:
			className: 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .OverlayContainer import OverlayContainer
from .TextInput import TextInput
from .IOverlayParent import IOverlayParent

Consumer = TypeVar["java.util.function.Consumer_java.lang.String_"]
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
Text = TypeVar["net.minecraft.text.Text"]
TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]

class TextPrompt(OverlayContainer):
	ti: TextInput

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, message: Text, defaultText: str, parent: IOverlayParent, accept: Consumer) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Set
from .IFontManager import IFontManager

Identifier = TypeVar["net.minecraft.util.Identifier"]

class MixinFontManager(IFontManager):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getFontList(self) -> Set[Identifier]:
		pass

	pass





from typing import overload
from typing import TypeVar
from .OverlayContainer import OverlayContainer
from .IOverlayParent import IOverlayParent
from .FileChooser_fileObj import FileChooser_fileObj

Consumer = TypeVar["java.util.function.Consumer_java.io.File_"]
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
File = TypeVar["java.io.File"]
TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]

class FileChooser(OverlayContainer):
	root: File

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, directory: File, selected: File, parent: IOverlayParent, setFile: Consumer, editFile: Consumer) -> None:
		pass

	@overload
	def setDir(self, dir: File) -> None:
		pass

	@overload
	def selectFile(self, f: File) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def addFile(self, f: File) -> None:
		pass

	@overload
	def addFile(self, f: File, btnText: str) -> None:
		pass

	@overload
	def updateFilePos(self) -> None:
		pass

	@overload
	def confirmDelete(self, f: FileChooser_fileObj) -> None:
		pass

	@overload
	def delete(self, f: FileChooser_fileObj) -> None:
		pass

	@overload
	def onScrollbar(self, page: float) -> None:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseScreen import BaseScreen
from .Core import Core

KeyBinding = TypeVar["net.minecraft.client.option.KeyBinding"]
Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]
MinecraftClient = TypeVar["net.minecraft.client.MinecraftClient"]
InputUtil_Key = TypeVar["net.minecraft.client.util.InputUtil.Key"]
Text = TypeVar["net.minecraft.text.Text"]
Logger = TypeVar["org.slf4j.Logger"]

class JsMacros:
	MOD_ID: str
	LOGGER: Logger
	keyBinding: KeyBinding
	prevScreen: BaseScreen
	core: Core

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onInitialize(self) -> None:
		pass

	@overload
	def onInitializeClient(self) -> None:
		pass

	@overload
	def getKeyText(self, translationKey: str) -> Text:
		pass

	@overload
	def getScreenName(self, s: Screen) -> str:
		pass

	@overload
	def getLocalizedName(self, keyCode: InputUtil_Key) -> str:
		pass

	@overload
	def getMinecraft(self) -> MinecraftClient:
		pass

	@overload
	def range(self, end: int) -> List[int]:
		pass

	@overload
	def range(self, start: int, end: int) -> List[int]:
		pass

	@overload
	def range(self, start: int, end: int, iter: int) -> List[int]:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .EntityHelper import EntityHelper

DamageSource = TypeVar["net.minecraft.entity.damage.DamageSource"]

class EventDamage(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	attacker: EntityHelper
	source: str
	health: float
	change: float

	@overload
	def __init__(self, source: DamageSource, health: float, change: float) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .RenderCommon_RenderElement import RenderCommon_RenderElement
from .TextHelper import TextHelper

MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
Text = TypeVar["net.minecraft.text.Text"]

class RenderCommon_Text(RenderCommon_RenderElement):
	"""
	Since: 1.0.5 
	"""
	text: Text
	scale: float
	rotation: float
	x: int
	y: int
	color: int
	width: int
	shadow: bool
	zIndex: int

	@overload
	def __init__(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> None:
		pass

	@overload
	def __init__(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> None:
		pass

	@overload
	def setScale(self, scale: float) -> "RenderCommon_Text":
		"""
		Since: 1.0.5 

		Args:
			scale: 
		"""
		pass

	@overload
	def setRotation(self, rotation: float) -> "RenderCommon_Text":
		"""
		Since: 1.0.5 

		Args:
			rotation: 
		"""
		pass

	@overload
	def setPos(self, x: int, y: int) -> "RenderCommon_Text":
		"""
		Since: 1.0.5 

		Args:
			x: 
			y: 
		"""
		pass

	@overload
	def setText(self, text: str) -> "RenderCommon_Text":
		"""
		Since: 1.0.5 

		Args:
			text: 
		"""
		pass

	@overload
	def setText(self, text: TextHelper) -> "RenderCommon_Text":
		"""
		Since: 1.2.7 

		Args:
			text: 
		"""
		pass

	@overload
	def getText(self) -> TextHelper:
		"""
		Since: 1.2.7 
		"""
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def render3D(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def getZIndex(self) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from .RenderCommon_RenderElement import RenderCommon_RenderElement

MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]

class RenderCommon_Image(RenderCommon_RenderElement):
	"""
	Since: 1.2.3 
	"""
	rotation: float
	x: int
	y: int
	width: int
	height: int
	imageX: int
	imageY: int
	regionWidth: int
	regionHeight: int
	textureWidth: int
	textureHeight: int
	color: int
	zIndex: int

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, zIndex: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> None:
		pass

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, zIndex: int, alpha: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> None:
		pass

	@overload
	def setColor(self, color: int) -> "RenderCommon_Image":
		"""
		Since: 1.6.5 

		Args:
			color: 
		"""
		pass

	@overload
	def setColor(self, color: int, alpha: int) -> "RenderCommon_Image":
		"""
		Since: 1.6.5 

		Args:
			color: 
			alpha: 
		"""
		pass

	@overload
	def setPos(self, x: int, y: int, width: int, height: int) -> None:
		"""
		Since: 1.2.3 

		Args:
			x: 
			width: 
			y: 
			height: 
		"""
		pass

	@overload
	def setRotation(self, rotation: float) -> "RenderCommon_Image":
		"""
		Since: 1.2.6 

		Args:
			rotation: 
		"""
		pass

	@overload
	def setImage(self, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> None:
		"""
		Since: 1.2.3 

		Args:
			imageY: 
			textureWidth: 
			imageX: 
			regionHeight: 
			id: 
			regionWidth: 
			textureHeight: 
		"""
		pass

	@overload
	def getImage(self) -> str:
		"""
		Since: 1.2.3 
		"""
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def getZIndex(self) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper

Runnable = TypeVar["java.lang.Runnable"]
Style = TypeVar["net.minecraft.text.Style"]

class StyleHelper(BaseHelper):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, base: Style) -> None:
		pass

	@overload
	def hasColor(self) -> bool:
		pass

	@overload
	def getColor(self) -> int:
		pass

	@overload
	def hasCustomColor(self) -> bool:
		pass

	@overload
	def getCustomColor(self) -> int:
		pass

	@overload
	def bold(self) -> bool:
		pass

	@overload
	def italic(self) -> bool:
		pass

	@overload
	def underlined(self) -> bool:
		pass

	@overload
	def strikethrough(self) -> bool:
		pass

	@overload
	def obfuscated(self) -> bool:
		pass

	@overload
	def getClickAction(self) -> str:
		pass

	@overload
	def getClickValue(self) -> str:
		pass

	@overload
	def getCustomClickValue(self) -> Runnable:
		pass

	@overload
	def getHoverAction(self) -> str:
		pass

	@overload
	def getHoverValue(self) -> object:
		pass

	@overload
	def getInsertion(self) -> str:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .IDraw2D import IDraw2D
from .MethodWrapper import MethodWrapper
from .RenderCommon_Text import RenderCommon_Text
from .RenderCommon_Rect import RenderCommon_Rect
from .RenderCommon_Item import RenderCommon_Item
from .RenderCommon_Image import RenderCommon_Image
from .RenderCommon_RenderElement import RenderCommon_RenderElement
from .TextHelper import TextHelper
from .ItemStackHelper import ItemStackHelper

DrawableHelper = TypeVar["net.minecraft.client.gui.DrawableHelper"]
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]

class Draw2D(IDraw2D, DrawableHelper):
	"""
	Since: 1.0.5 
	"""
	onInit: MethodWrapper
	catchInit: MethodWrapper

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getTexts(self) -> List[RenderCommon_Text]:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getRects(self) -> List[RenderCommon_Rect]:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getItems(self) -> List[RenderCommon_Item]:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def getImages(self) -> List[RenderCommon_Image]:
		"""
		Since: 1.2.3 
		"""
		pass

	@overload
	def getElements(self) -> List[RenderCommon_RenderElement]:
		pass

	@overload
	def removeElement(self, e: RenderCommon_RenderElement) -> "Draw2D":
		pass

	@overload
	def reAddElement(self, e: RenderCommon_RenderElement) -> RenderCommon_RenderElement:
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, shadow: bool) -> RenderCommon_Text:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool) -> RenderCommon_Text:
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, shadow: bool, scale: float, rotation: float) -> RenderCommon_Text:
		"""
		Since: 1.2.6 
		"""
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> RenderCommon_Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, shadow: bool) -> RenderCommon_Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool) -> RenderCommon_Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, shadow: bool, scale: float, rotation: float) -> RenderCommon_Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> RenderCommon_Text:
		pass

	@overload
	def removeText(self, t: RenderCommon_Text) -> "Draw2D":
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> RenderCommon_Image:
		"""
		Since: 1.2.3 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> RenderCommon_Image:
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
		"""
		Since: 1.2.6 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
		"""
		Since: 1.4.0 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, alpha: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def removeImage(self, i: RenderCommon_Image) -> "Draw2D":
		"""
		Since: 1.2.3 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int) -> RenderCommon_Rect:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int) -> RenderCommon_Rect:
		"""
		Since: 1.1.8 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float) -> RenderCommon_Rect:
		"""
		Since: 1.2.6 
		"""
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float, zIndex: int) -> RenderCommon_Rect:
		pass

	@overload
	def removeRect(self, r: RenderCommon_Rect) -> "Draw2D":
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, id: str) -> RenderCommon_Item:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool) -> RenderCommon_Item:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str, overlay: bool) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, Item: ItemStackHelper) -> RenderCommon_Item:
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, Item: ItemStackHelper, overlay: bool) -> RenderCommon_Item:
		"""
		Since: 1.2.0 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper, overlay: bool) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		"""
		Since: 1.2.6 
		"""
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		pass

	@overload
	def removeItem(self, i: RenderCommon_Item) -> "Draw2D":
		"""
		Since: 1.0.5 
		"""
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def render(self, matrixStack: MatrixStack) -> None:
		pass

	@overload
	def setOnInit(self, onInit: MethodWrapper) -> "Draw2D":
		"""init function, called when window is resized or screen/draw2d is registered.
clears all previous elements when called.\n
		Since: 1.2.7 

		Args:
			onInit: calls your method as a Consumer Draw2D 
		"""
		pass

	@overload
	def setOnFailInit(self, catchInit: MethodWrapper) -> "Draw2D":
		"""
		Since: 1.2.7 

		Args:
			catchInit: calls your method as a Consumer String 
		"""
		pass

	@overload
	def register(self) -> "Draw2D":
		"""register so the overlay actually renders\n
		Since: 1.6.5 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def unregister(self) -> "Draw2D":
		"""unregister so the overlay stops rendering\n
		Since: 1.6.5 

		Returns:
			self for chaining 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .Draw3D_Box import Draw3D_Box
from .Draw3D_Line import Draw3D_Line
from .Draw3D_Surface import Draw3D_Surface
from .PositionCommon_Pos3D import PositionCommon_Pos3D

MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]

class Draw3D:
	"""Draw2D is cool\n
	Since: 1.0.6 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def getBoxes(self) -> List[Draw3D_Box]:
		"""
		Since: 1.0.6 
		"""
		pass

	@overload
	def getLines(self) -> List[Draw3D_Line]:
		"""
		Since: 1.0.6 
		"""
		pass

	@overload
	def getDraw2Ds(self) -> List[Draw3D_Surface]:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def addBox(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, fillColor: int, fill: bool) -> Draw3D_Box:
		"""
		Since: 1.0.6 

		Args:
			fillColor: 
			color: 
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
			fill: 

		Returns:
			The Draw3D_Box you added. 
		"""
		pass

	@overload
	def addBox(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, fillColor: int, fill: bool, cull: bool) -> Draw3D_Box:
		"""
		Since: 1.3.1 

		Args:
			fillColor: 
			color: 
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
			fill: 
			cull: 
		"""
		pass

	@overload
	def addBox(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, alpha: int, fillColor: int, fillAlpha: int, fill: bool) -> Draw3D_Box:
		"""
		Since: 1.1.8 

		Args:
			fillColor: 
			color: 
			z1: 
			alpha: 
			y1: 
			z2: 
			x1: 
			y2: 
			fillAlpha: 
			x2: 
			fill: 

		Returns:
			the Draw3D_Box you added. 
		"""
		pass

	@overload
	def addBox(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, alpha: int, fillColor: int, fillAlpha: int, fill: bool, cull: bool) -> Draw3D_Box:
		pass

	@overload
	def removeBox(self, b: Draw3D_Box) -> "Draw3D":
		"""
		Since: 1.0.6 

		Args:
			b: 
		"""
		pass

	@overload
	def addLine(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int) -> Draw3D_Line:
		"""
		Since: 1.0.6 

		Args:
			color: 
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 

		Returns:
			the Draw3D_Line you added. 
		"""
		pass

	@overload
	def addLine(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, cull: bool) -> Draw3D_Line:
		"""
		Since: 1.3.1 

		Args:
			color: 
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
			cull: 
		"""
		pass

	@overload
	def addLine(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, alpha: int) -> Draw3D_Line:
		"""
		Since: 1.1.8 

		Args:
			color: 
			z1: 
			alpha: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 

		Returns:
			the Draw3D_Line you added. 
		"""
		pass

	@overload
	def addLine(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, color: int, alpha: int, cull: bool) -> Draw3D_Line:
		"""
		Since: 1.3.1 

		Args:
			color: 
			z1: 
			alpha: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
			cull: 
		"""
		pass

	@overload
	def removeLine(self, l: Draw3D_Line) -> "Draw3D":
		"""
		Since: 1.0.6 

		Args:
			l: 
		"""
		pass

	@overload
	def addPoint(self, point: PositionCommon_Pos3D, radius: float, color: int) -> Draw3D_Box:
		"""Draws a cube( Draw3D_Box ) with a specific radius( 'side length = 2*radius' )\n
		Since: 1.4.0 

		Args:
			color: point color 
			radius: 1/2 of the side length of the cube 
			point: the center point 

		Returns:
			the Draw3D_Box generated, and visualized 
		"""
		pass

	@overload
	def addPoint(self, x: float, y: float, z: float, radius: float, color: int) -> Draw3D_Box:
		"""Draws a cube( Draw3D_Box ) with a specific radius( 'side length = 2*radius' )\n
		Since: 1.4.0 

		Args:
			color: point color 
			x: x value of the center point 
			y: y value of the center point 
			z: z value of the center point 
			radius: 1/2 of the side length of the cube 

		Returns:
			the Draw3D_Box generated, and visualized 
		"""
		pass

	@overload
	def addPoint(self, x: float, y: float, z: float, radius: float, color: int, alpha: int, cull: bool) -> Draw3D_Box:
		"""Draws a cube( Draw3D_Box ) with a specific radius( 'side length = 2*radius' )\n
		Since: 1.4.0 

		Args:
			color: point color 
			alpha: alpha of the point 
			x: x value of the center point 
			y: y value of the center point 
			z: z value of the center point 
			radius: 1/2 of the side length of the cube 
			cull: whether to cull the point or not 

		Returns:
			the Draw3D_Box generated, and visualized 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float) -> Draw3D_Surface:
		"""
		Since: 1.6.5 

		Args:
			x: top left 
			y: 
			z: 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float, width: float, height: float) -> Draw3D_Surface:
		"""
		Since: 1.6.5 

		Args:
			x: 
			width: 
			y: 
			z: 
			height: 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float) -> Draw3D_Surface:
		"""
		Since: 1.6.5 

		Args:
			zRot: 
			yRot: 
			x: 
			xRot: 
			y: 
			z: 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float, width: float, height: float) -> Draw3D_Surface:
		"""
		Since: 1.6.5 

		Args:
			zRot: 
			yRot: 
			x: 
			xRot: 
			width: 
			y: 
			z: 
			height: 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float, width: float, height: float, minSubdivisions: int) -> Draw3D_Surface:
		"""
		Since: 1.6.5 

		Args:
			zRot: 
			yRot: 
			x: 
			xRot: 
			width: 
			y: 
			z: 
			minSubdivisions: 
			height: 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float, width: float, height: float, minSubdivisions: int, renderBack: bool) -> Draw3D_Surface:
		"""
		Since: 1.6.5 

		Args:
			zRot: 
			yRot: 
			x: 
			xRot: 
			width: 
			y: 
			z: 
			minSubdivisions: 
			renderBack: 
			height: 
		"""
		pass

	@overload
	def addDraw2D(self, x: float, y: float, z: float, xRot: float, yRot: float, zRot: float, width: float, height: float, minSubdivisions: int, renderBack: bool, cull: bool) -> Draw3D_Surface:
		"""
		Since: 1.6.5 

		Args:
			zRot: 
			yRot: 
			x: top left 
			xRot: 
			width: 
			y: 
			z: 
			minSubdivisions: 
			renderBack: 
			height: 
		"""
		pass

	@overload
	def removeDraw2D(self, surface: Draw3D_Surface) -> None:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def register(self) -> "Draw3D":
		"""register so it actually shows up\n
		Since: 1.6.5 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def unregister(self) -> "Draw3D":
		"""
		Since: 1.6.5 

		Returns:
			self for chaining 
		"""
		pass

	@overload
	def render(self, matrixStack: MatrixStack) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

CallbackInfo = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfo"]

class MixinHungerManager:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onSetFoodLevel(self, foodLevel: int, info: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseHelper import BaseHelper
from .VillagerInventory import VillagerInventory
from .ItemStackHelper import ItemStackHelper
from .NBTElementHelper import NBTElementHelper

TradeOffer = TypeVar["net.minecraft.village.TradeOffer"]

class TradeOfferHelper(BaseHelper):

	@overload
	def __init__(self, base: TradeOffer, index: int, inv: VillagerInventory) -> None:
		pass

	@overload
	def getInput(self) -> List[ItemStackHelper]:
		"""

		Returns:
			list of input items required 
		"""
		pass

	@overload
	def getOutput(self) -> ItemStackHelper:
		"""

		Returns:
			output item that will be recieved 
		"""
		pass

	@overload
	def select(self) -> None:
		"""select trade offer on screen
		"""
		pass

	@overload
	def isAvailable(self) -> bool:
		"""
		"""
		pass

	@overload
	def getNBT(self) -> NBTElementHelper:
		"""

		Returns:
			trade offer as nbt tag 
		"""
		pass

	@overload
	def getUses(self) -> int:
		"""

		Returns:
			current number of uses 
		"""
		pass

	@overload
	def getMaxUses(self) -> int:
		"""

		Returns:
			max uses before it locks 
		"""
		pass

	@overload
	def getExperience(self) -> int:
		"""

		Returns:
			experience gained for trade 
		"""
		pass

	@overload
	def getCurrentPriceAdjustment(self) -> int:
		"""

		Returns:
			current price adjustment, negative is discount. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

MinecraftClient = TypeVar["net.minecraft.client.MinecraftClient"]
MultiplayerServerListPinger = TypeVar["net.minecraft.client.network.MultiplayerServerListPinger"]
ItemStack = TypeVar["net.minecraft.item.ItemStack"]

class TickBasedEvents:
	serverListPinger: MultiplayerServerListPinger

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def areNotEqual(self, a: ItemStack, b: ItemStack) -> bool:
		pass

	@overload
	def areTagsEqualIgnoreDamage(self, a: ItemStack, b: ItemStack) -> bool:
		pass

	@overload
	def areEqualIgnoreDamage(self, a: ItemStack, b: ItemStack) -> bool:
		pass

	@overload
	def onTick(self, mc: MinecraftClient) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .IChatHud import IChatHud

CallbackInfo = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfo"]
MinecraftClient = TypeVar["net.minecraft.client.MinecraftClient"]
ChatHudLine = TypeVar["net.minecraft.client.gui.hud.ChatHudLine"]
Text = TypeVar["net.minecraft.text.Text"]
Predicate = TypeVar["java.util.function.Predicate_net.minecraft.client.gui.hud.ChatHudLine_"]

class MixinChatHud(IChatHud):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onInit(self, client: MinecraftClient, ci: CallbackInfo) -> None:
		pass

	@overload
	def jsmacros_addMessageBypass(self, message: Text) -> None:
		pass

	@overload
	def jsmacros_getMessages(self) -> List[ChatHudLine]:
		pass

	@overload
	def jsmacros_removeMessageById(self, messageId: int) -> None:
		pass

	@overload
	def jsmacros_addMessageAtIndexBypass(self, message: Text, index: int, time: int) -> None:
		pass

	@overload
	def overrideMessagePos(self, pos: int) -> int:
		pass

	@overload
	def jsmacros_removeMessage(self, index: int) -> None:
		pass

	@overload
	def jsmacros_removeMessageByText(self, text: Text) -> None:
		pass

	@overload
	def jsmacros_removeMessagePredicate(self, textfilter: Predicate) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

Prism4j_Grammar = TypeVar["io.noties.prism4j.Prism4j.Grammar"]

class Prism_javascript:
	"""This class is from Prism4j under the Apache-2.0 license I updated template-strings to match with the JS version again, which made them work better. other updates.
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def create(self, prism4j: Prism4j) -> Prism4j_Grammar:
		pass

	pass





from typing import overload
from typing import TypeVar

Text = TypeVar["net.minecraft.text.Text"]

class IPlayerListHud:

	@overload
	def jsmacros_getHeader(self) -> Text:
		pass

	@overload
	def jsmacros_getFooter(self) -> Text:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic

C = TypeVar("C")
Predicate = TypeVar["java.util.function.Predicate_T_"]
Comparator = TypeVar["java.util.Comparator_T_"]
Thread = TypeVar["java.lang.Thread"]
Function = TypeVar["java.util.function.Function_T,R_"]
R = TypeVar("R")
T = TypeVar("T")
Consumer = TypeVar["java.util.function.Consumer_T_"]
U = TypeVar("U")
BiFunction = TypeVar["java.util.function.BiFunction_T,U,R_"]
Runnable = TypeVar["java.lang.Runnable"]
Supplier = TypeVar["java.util.function.Supplier_R_"]
BiConsumer = TypeVar["java.util.function.BiConsumer_T,U_"]
BiPredicate = TypeVar["java.util.function.BiPredicate_T,U_"]

class MethodWrapper(Consumer, BiConsumer, Function, BiFunction, Predicate, BiPredicate, Runnable, Supplier, Comparator, Generic[T, U, R, C]):
	"""Wraps most of the important functional interfaces.
	"""

	@overload
	def __init__(self, containingContext: C) -> None:
		pass

	@overload
	def getCtx(self) -> C:
		pass

	@overload
	def accept(self, t: T) -> None:
		pass

	@overload
	def accept(self, t: T, u: U) -> None:
		pass

	@overload
	def apply(self, t: T) -> R:
		pass

	@overload
	def apply(self, t: T, u: U) -> R:
		pass

	@overload
	def test(self, t: T) -> bool:
		pass

	@overload
	def test(self, t: T, u: U) -> bool:
		pass

	@overload
	def preventSameThreadJoin(self) -> bool:
		"""override to return true if the method can't join to the thread it was wrapped/created in, ie for languages that don't allow multithreading.
		"""
		pass

	@overload
	def overrideThread(self) -> Thread:
		"""make return something to override the thread set in FJsMacros#on(java.lang.String,xyz.wagyourtail.jsmacros.core.MethodWrapper<xyz.wagyourtail.jsmacros.core.event.BaseEvent,xyz.wagyourtail.jsmacros.core.language.EventContainer<?>,java.lang.Object,?>) (hi jep)
		"""
		pass

	@overload
	def andThen(self, after: Function) -> "MethodWrapper":
		"""Makes Function and BiFunction work together.
Extended so it's called on every type not just those 2.

		Args:
			after: put a MethodWrapper here when using in scripts. 
		"""
		pass

	@overload
	def negate(self) -> "MethodWrapper":
		"""Makes Predicate and BiPredicate work together
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import Mapping
from .BaseLibrary import BaseLibrary
from .PlayerEntityHelper import PlayerEntityHelper
from .PlayerListEntryHelper import PlayerListEntryHelper
from .BlockDataHelper import BlockDataHelper
from .PositionCommon_Pos3D import PositionCommon_Pos3D
from .BlockPosHelper import BlockPosHelper
from .WorldScannerBuilder import WorldScannerBuilder
from .MethodWrapper import MethodWrapper
from .WorldScanner import WorldScanner
from .ScoreboardsHelper import ScoreboardsHelper
from .EntityHelper import EntityHelper
from .BossBarHelper import BossBarHelper
from .TextHelper import TextHelper


class FWorld(BaseLibrary):
	"""Functions for getting and using world data.

An instance of this class is passed to scripts as the 'World' variable.
	"""
	serverInstantTPS: float
	server1MAverageTPS: float
	server5MAverageTPS: float
	server15MAverageTPS: float

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def isWorldLoaded(self) -> bool:
		"""returns whether a world is currently loaded\n
		Since: 1.3.0 
		"""
		pass

	@overload
	def getLoadedPlayers(self) -> List[PlayerEntityHelper]:
		"""

		Returns:
			players within render distance. 
		"""
		pass

	@overload
	def getPlayers(self) -> List[PlayerListEntryHelper]:
		"""

		Returns:
			players on the tablist. 
		"""
		pass

	@overload
	def getBlock(self, x: int, y: int, z: int) -> BlockDataHelper:
		"""

		Args:
			x: 
			y: 
			z: 

		Returns:
			The block at that position. 
		"""
		pass

	@overload
	def getBlock(self, pos: PositionCommon_Pos3D) -> BlockDataHelper:
		pass

	@overload
	def getBlock(self, pos: BlockPosHelper) -> BlockDataHelper:
		pass

	@overload
	def getWorldScanner(self) -> WorldScannerBuilder:
		"""Usage: This will return all blocks that are facing south, don't require a tool to break, 
have a hardness of 10 or less and whose name contains either chest or barrel. World.getWorldScanner()
    .withBlockFilter("getHardness").is(" =", 10)
    .andStringBlockFilter().contains("chest", "barrel")
    .withStringStateFilter().contains("facing=south")
    .andStateFilter("isToolRequired").is(false)
    .build()\n
		Since: 1.6.5 

		Returns:
			a builder to create a WorldScanner 
		"""
		pass

	@overload
	def getWorldScanner(self, blockFilter: MethodWrapper, stateFilter: MethodWrapper) -> WorldScanner:
		"""
		Since: 1.6.5 

		Returns:
			a scanner for the current world 
		"""
		pass

	@overload
	def findBlocksMatching(self, centerX: int, centerZ: int, id: str, chunkrange: int) -> List[PositionCommon_Pos3D]:
		"""
		Since: 1.6.4 

		Args:
			chunkrange: 
			id: 
		"""
		pass

	@overload
	def findBlocksMatching(self, id: str, chunkrange: int) -> List[PositionCommon_Pos3D]:
		"""
		Since: 1.6.4 

		Args:
			chunkrange: 
			id: 
		"""
		pass

	@overload
	def findBlocksMatching(self, ids: List[str], chunkrange: int) -> List[PositionCommon_Pos3D]:
		"""
		Since: 1.6.4 

		Args:
			chunkrange: 
			ids: 
		"""
		pass

	@overload
	def findBlocksMatching(self, centerX: int, centerZ: int, ids: List[str], chunkrange: int) -> List[PositionCommon_Pos3D]:
		"""
		Since: 1.6.4 

		Args:
			centerZ: 
			centerX: 
			chunkrange: 
			ids: 
		"""
		pass

	@overload
	def findBlocksMatching(self, blockFilter: MethodWrapper, stateFilter: MethodWrapper, chunkrange: int) -> List[PositionCommon_Pos3D]:
		"""
		Since: 1.6.4 

		Args:
			blockFilter: 
			stateFilter: 
			chunkrange: 
		"""
		pass

	@overload
	def findBlocksMatching(self, chunkX: int, chunkZ: int, blockFilter: MethodWrapper, stateFilter: MethodWrapper, chunkrange: int) -> List[PositionCommon_Pos3D]:
		"""
		Since: 1.6.4 

		Args:
			blockFilter: 
			stateFilter: 
			chunkrange: 
			chunkX: 
			chunkZ: 
		"""
		pass

	@overload
	def getScoreboards(self) -> ScoreboardsHelper:
		"""
		Since: 1.2.9 

		Returns:
			a helper for the scoreboards provided to the client. 
		"""
		pass

	@overload
	def getEntities(self) -> List[EntityHelper]:
		"""

		Returns:
			all entities in the render distance. 
		"""
		pass

	@overload
	def rayTraceBlock(self, x1: int, y1: int, z1: int, x2: int, y2: int, z2: int, fluid: bool) -> BlockDataHelper:
		"""raytrace between two points returning the first block hit.\n
		Since: 1.6.5 

		Args:
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
			fluid: 
		"""
		pass

	@overload
	def getDimension(self) -> str:
		"""
		Since: 1.1.2 

		Returns:
			the current dimension. 
		"""
		pass

	@overload
	def getBiome(self) -> str:
		"""
		Since: 1.1.5 

		Returns:
			the current biome. 
		"""
		pass

	@overload
	def getTime(self) -> float:
		"""
		Since: 1.1.5 

		Returns:
			the current world time. 
		"""
		pass

	@overload
	def getTimeOfDay(self) -> float:
		"""This is supposed to be time of day, but it appears to be the same as FWorld#getTime() to me...\n
		Since: 1.1.5 

		Returns:
			the current world time of day. 
		"""
		pass

	@overload
	def getRespawnPos(self) -> BlockPosHelper:
		"""
		Since: 1.2.6 

		Returns:
			respawn position. 
		"""
		pass

	@overload
	def getDifficulty(self) -> int:
		"""
		Since: 1.2.6 

		Returns:
			world difficulty as an Integer . 
		"""
		pass

	@overload
	def getMoonPhase(self) -> int:
		"""
		Since: 1.2.6 

		Returns:
			moon phase as an Integer . 
		"""
		pass

	@overload
	def getSkyLight(self, x: int, y: int, z: int) -> int:
		"""
		Since: 1.1.2 

		Args:
			x: 
			y: 
			z: 

		Returns:
			sky light as an Integer . 
		"""
		pass

	@overload
	def getBlockLight(self, x: int, y: int, z: int) -> int:
		"""
		Since: 1.1.2 

		Args:
			x: 
			y: 
			z: 

		Returns:
			block light as an Integer . 
		"""
		pass

	@overload
	def playSoundFile(self, file: str, volume: float) -> Clip:
		"""plays a sound file using javax's sound stuff.\n
		Since: 1.1.7 

		Args:
			volume: 
			file: 
		"""
		pass

	@overload
	def playSound(self, id: str) -> None:
		"""
		Since: 1.1.7 

		Args:
			id: 
		"""
		pass

	@overload
	def playSound(self, id: str, volume: float) -> None:
		"""
		Since: 1.1.7 

		Args:
			volume: 
			id: 
		"""
		pass

	@overload
	def playSound(self, id: str, volume: float, pitch: float) -> None:
		"""
		Since: 1.1.7 

		Args:
			volume: 
			id: 
			pitch: 
		"""
		pass

	@overload
	def playSound(self, id: str, volume: float, pitch: float, x: float, y: float, z: float) -> None:
		"""plays a minecraft sound using the internal system.\n
		Since: 1.1.7 

		Args:
			volume: 
			x: 
			y: 
			z: 
			id: 
			pitch: 
		"""
		pass

	@overload
	def getBossBars(self) -> Mapping[str, BossBarHelper]:
		"""
		Since: 1.2.1 

		Returns:
			a map of boss bars by the boss bar's UUID. 
		"""
		pass

	@overload
	def isChunkLoaded(self, chunkX: int, chunkZ: int) -> bool:
		"""Check whether a chunk is within the render distance and loaded.\n
		Since: 1.2.2 

		Args:
			chunkX: 
			chunkZ: 
		"""
		pass

	@overload
	def getCurrentServerAddress(self) -> str:
		"""
		Since: 1.2.2 

		Returns:
			the current server address as a string ( 'server.address/server.ip:port' ). 
		"""
		pass

	@overload
	def getBiomeAt(self, x: int, z: int) -> str:
		"""
		Since: 1.2.2 [Citation Needed] 

		Args:
			x: 
			z: 

		Returns:
			biome at specified location, only works if the block/chunk is loaded. 
		"""
		pass

	@overload
	def getServerTPS(self) -> str:
		"""
		Since: 1.2.7 

		Returns:
			best attempt to measure and give the server tps with various timings. 
		"""
		pass

	@overload
	def getTabListHeader(self) -> TextHelper:
		"""
		Since: 1.3.1 

		Returns:
			text helper for the top part of the tab list (above the players) 
		"""
		pass

	@overload
	def getTabListFooter(self) -> TextHelper:
		"""
		Since: 1.3.1 

		Returns:
			text helper for the bottom part of the tab list (below the players) 
		"""
		pass

	@overload
	def getServerInstantTPS(self) -> float:
		"""
		Since: 1.2.7 

		Returns:
			best attempt to measure and give the server tps. 
		"""
		pass

	@overload
	def getServer1MAverageTPS(self) -> float:
		"""
		Since: 1.2.7 

		Returns:
			best attempt to measure and give the server tps over the previous 1 minute average. 
		"""
		pass

	@overload
	def getServer5MAverageTPS(self) -> float:
		"""
		Since: 1.2.7 

		Returns:
			best attempt to measure and give the server tps over the previous 5 minute average. 
		"""
		pass

	@overload
	def getServer15MAverageTPS(self) -> float:
		"""
		Since: 1.2.7 

		Returns:
			best attempt to measure and give the server tps over the previous 15 minute average. 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .PositionCommon_Pos2D import PositionCommon_Pos2D
from .PositionCommon_Vec3D import PositionCommon_Vec3D
from .BlockPosHelper import BlockPosHelper

BlockPos = TypeVar["net.minecraft.util.math.BlockPos"]
Vec3d = TypeVar["net.minecraft.util.math.Vec3d"]

class PositionCommon_Pos3D(PositionCommon_Pos2D):
	"""
	Since: 1.2.6 [citation needed] 
	"""
	ZERO: "PositionCommon_Pos3D"
	z: float

	@overload
	def __init__(self, vec: Vec3d) -> None:
		pass

	@overload
	def __init__(self, x: float, y: float, z: float) -> None:
		pass

	@overload
	def getZ(self) -> float:
		pass

	@overload
	def add(self, pos: "PositionCommon_Pos3D") -> "PositionCommon_Pos3D":
		pass

	@overload
	def add(self, x: float, y: float, z: float) -> "PositionCommon_Pos3D":
		"""
		Since: 1.6.3 

		Args:
			x: 
			y: 
			z: 
		"""
		pass

	@overload
	def multiply(self, pos: "PositionCommon_Pos3D") -> "PositionCommon_Pos3D":
		pass

	@overload
	def multiply(self, x: float, y: float, z: float) -> "PositionCommon_Pos3D":
		"""
		Since: 1.6.3 

		Args:
			x: 
			y: 
			z: 
		"""
		pass

	@overload
	def scale(self, scale: float) -> "PositionCommon_Pos3D":
		"""
		Since: 1.6.3 

		Args:
			scale: 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	@overload
	def toVector(self) -> PositionCommon_Vec3D:
		pass

	@overload
	def toVector(self, start_pos: PositionCommon_Pos2D) -> PositionCommon_Vec3D:
		"""
		Since: 1.6.4 

		Args:
			start_pos: 
		"""
		pass

	@overload
	def toVector(self, start_pos: "PositionCommon_Pos3D") -> PositionCommon_Vec3D:
		"""
		Since: 1.6.4 

		Args:
			start_pos: 
		"""
		pass

	@overload
	def toVector(self, start_x: float, start_y: float, start_z: float) -> PositionCommon_Vec3D:
		"""
		Since: 1.6.4 

		Args:
			start_x: 
			start_z: 
			start_y: 
		"""
		pass

	@overload
	def toReverseVector(self) -> PositionCommon_Vec3D:
		"""
		Since: 1.6.4 
		"""
		pass

	@overload
	def toReverseVector(self, end_pos: PositionCommon_Pos2D) -> PositionCommon_Vec3D:
		pass

	@overload
	def toReverseVector(self, end_pos: "PositionCommon_Pos3D") -> PositionCommon_Vec3D:
		"""
		Since: 1.6.4 

		Args:
			end_pos: 
		"""
		pass

	@overload
	def toReverseVector(self, end_x: float, end_y: float, end_z: float) -> PositionCommon_Vec3D:
		"""
		Since: 1.6.4 

		Args:
			end_z: 
			end_x: 
			end_y: 
		"""
		pass

	@overload
	def toBlockPos(self) -> BlockPosHelper:
		"""
		Since: 1.8.0 
		"""
		pass

	@overload
	def toRawBlockPos(self) -> BlockPos:
		"""
		Since: 1.8.0 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .ButtonWidgetHelper import ButtonWidgetHelper

TextFieldWidget = TypeVar["net.minecraft.client.gui.widget.TextFieldWidget"]

class TextFieldWidgetHelper(ButtonWidgetHelper):
	"""F\n
	Since: 1.0.5 
	"""

	@overload
	def __init__(self, t: TextFieldWidget) -> None:
		pass

	@overload
	def __init__(self, t: TextFieldWidget, zIndex: int) -> None:
		pass

	@overload
	def getText(self) -> str:
		"""
		Since: 1.0.5 

		Returns:
			the currently entered String . 
		"""
		pass

	@overload
	def setText(self, text: str) -> "TextFieldWidgetHelper":
		"""
		Since: 1.0.5 

		Args:
			text: 
		"""
		pass

	@overload
	def setText(self, text: str, await_: bool) -> "TextFieldWidgetHelper":
		"""set the currently entered String .\n
		Since: 1.3.1 

		Args:
			await: 
			text: 
		"""
		pass

	@overload
	def setEditableColor(self, color: int) -> "TextFieldWidgetHelper":
		"""
		Since: 1.0.5 

		Args:
			color: 
		"""
		pass

	@overload
	def setEditable(self, edit: bool) -> "TextFieldWidgetHelper":
		"""
		Since: 1.0.5 

		Args:
			edit: 
		"""
		pass

	@overload
	def setUneditableColor(self, color: int) -> "TextFieldWidgetHelper":
		"""
		Since: 1.0.5 

		Args:
			color: 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .RunningContextContainer import RunningContextContainer

Comparator = TypeVar["java.util.Comparator_xyz.wagyourtail.jsmacros.client.gui.containers.RunningContextContainer_"]

class CancelScreen_RTCSort(Comparator):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def compare(self, arg0: RunningContextContainer, arg1: RunningContextContainer) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar

Text = TypeVar["net.minecraft.text.Text"]

class TranslationUtil:

	@overload
	def getTranslatedEventName(self, eventName: str) -> Text:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar

RecipeResultCollection = TypeVar["net.minecraft.client.gui.screen.recipebook.RecipeResultCollection"]

class IRecipeBookResults:

	@overload
	def jsmacros_getResultCollections(self) -> List[RecipeResultCollection]:
		pass

	pass





from typing import overload
from typing import TypeVar
from .RenderCommon_RenderElement import RenderCommon_RenderElement
from .ItemStackHelper import ItemStackHelper

MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
ItemStack = TypeVar["net.minecraft.item.ItemStack"]

class RenderCommon_Item(RenderCommon_RenderElement):
	"""
	Since: 1.0.5 
	"""
	item: ItemStack
	ovText: str
	overlay: bool
	scale: float
	rotation: float
	x: int
	y: int
	zIndex: int

	@overload
	def __init__(self, x: int, y: int, zIndex: int, id: str, overlay: bool, scale: float, rotation: float) -> None:
		pass

	@overload
	def __init__(self, x: int, y: int, zIndex: int, i: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> None:
		pass

	@overload
	def setPos(self, x: int, y: int) -> "RenderCommon_Item":
		"""
		Since: 1.0.5 

		Args:
			x: 
			y: 
		"""
		pass

	@overload
	def setScale(self, scale: float) -> "RenderCommon_Item":
		"""
		Since: 1.2.6 

		Args:
			scale: 
		"""
		pass

	@overload
	def setRotation(self, rotation: float) -> "RenderCommon_Item":
		"""
		Since: 1.2.6 

		Args:
			rotation: 
		"""
		pass

	@overload
	def setOverlay(self, overlay: bool) -> "RenderCommon_Item":
		"""
		Since: 1.2.0 

		Args:
			overlay: 
		"""
		pass

	@overload
	def setOverlayText(self, ovText: str) -> "RenderCommon_Item":
		"""
		Since: 1.2.0 

		Args:
			ovText: 
		"""
		pass

	@overload
	def setItem(self, i: ItemStackHelper) -> "RenderCommon_Item":
		"""
		Since: 1.0.5 [citation needed] 

		Args:
			i: 
		"""
		pass

	@overload
	def setItem(self, id: str, count: int) -> "RenderCommon_Item":
		"""
		Since: 1.0.5 [citation needed] 

		Args:
			count: 
			id: 
		"""
		pass

	@overload
	def getItem(self) -> ItemStackHelper:
		"""
		Since: 1.0.5 [citation needed] 
		"""
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def render3D(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def getZIndex(self) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from .IItemCooldownManager import IItemCooldownManager
from .IItemCooldownEntry import IItemCooldownEntry

Item = TypeVar["net.minecraft.item.Item"]

class MixinItemCooldownManager(IItemCooldownManager):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def getCooldownItems(self) -> Mapping[Item, IItemCooldownEntry]:
		pass

	@overload
	def getManagerTicks(self) -> int:
		pass

	pass





from typing import overload
from .BaseLibrary import BaseLibrary
from .PositionCommon_Vec3D import PositionCommon_Vec3D
from .PositionCommon_Vec2D import PositionCommon_Vec2D
from .PositionCommon_Pos3D import PositionCommon_Pos3D
from .PositionCommon_Pos2D import PositionCommon_Pos2D


class FPositionCommon(BaseLibrary):
	"""position helper classes\n
	Since: 1.6.3 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def createVec(self, x1: float, y1: float, z1: float, x2: float, y2: float, z2: float) -> PositionCommon_Vec3D:
		"""create a new vector object\n
		Since: 1.6.3 

		Args:
			z1: 
			y1: 
			z2: 
			x1: 
			y2: 
			x2: 
		"""
		pass

	@overload
	def createVec(self, x1: float, y1: float, x2: float, y2: float) -> PositionCommon_Vec2D:
		"""
		Since: 1.6.3 

		Args:
			y1: 
			x1: 
			y2: 
			x2: 
		"""
		pass

	@overload
	def createPos(self, x: float, y: float, z: float) -> PositionCommon_Pos3D:
		"""
		Since: 1.6.3 

		Args:
			x: 
			y: 
			z: 
		"""
		pass

	@overload
	def createPos(self, x: float, y: float) -> PositionCommon_Pos2D:
		"""
		Since: 1.6.3 

		Args:
			x: 
			y: 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .BaseProfile import BaseProfile
from .Core import Core
from .BaseEvent import BaseEvent

Throwable = TypeVar["java.lang.Throwable"]
Logger = TypeVar["org.slf4j.Logger"]

class Profile(BaseProfile):
	ignoredErrors: List[Class]

	@overload
	def __init__(self, runner: Core, logger: Logger) -> None:
		pass

	@overload
	def triggerEventJoin(self, event: BaseEvent) -> None:
		pass

	@overload
	def triggerEventJoinNoAnything(self, event: BaseEvent) -> None:
		pass

	@overload
	def logError(self, ex: Throwable) -> None:
		pass

	@overload
	def checkJoinedThreadStack(self) -> bool:
		pass

	@overload
	def initRegistries(self) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseScreen import BaseScreen
from .BaseScriptContext import BaseScriptContext
from .RunningContextContainer import RunningContextContainer

Screen = TypeVar["net.minecraft.client.gui.screen.Screen"]
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]

class CancelScreen(BaseScreen):

	@overload
	def __init__(self, parent: Screen) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def addContainer(self, t: BaseScriptContext) -> None:
		pass

	@overload
	def removeContainer(self, t: RunningContextContainer) -> None:
		pass

	@overload
	def updatePos(self) -> None:
		pass

	@overload
	def mouseScrolled(self, mouseX: float, mouseY: float, amount: float) -> bool:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def removed(self) -> None:
		pass

	@overload
	def close(self) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .ItemStackHelper import ItemStackHelper

ItemStack = TypeVar["net.minecraft.item.ItemStack"]

class EventArmorChange(BaseEvent):
	"""
	Since: 1.2.7 
	"""
	slot: str
	item: ItemStackHelper
	oldItem: ItemStackHelper

	@overload
	def __init__(self, slot: str, item: ItemStack, old: ItemStack) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar

CallbackInfo = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfo"]

class MixinLivingEntity:

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def getMaxHealth(self) -> float:
		pass

	@overload
	def onSetHealth(self, health: float, ci: CallbackInfo) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
Drawable = TypeVar["net.minecraft.client.gui.Drawable"]

class RenderCommon_RenderElement(Drawable):

	@overload
	def getZIndex(self) -> int:
		pass

	@overload
	def render3D(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper

StatusEffectInstance = TypeVar["net.minecraft.entity.effect.StatusEffectInstance"]

class StatusEffectHelper(BaseHelper):
	"""
	Since: 1.2.4 
	"""

	@overload
	def __init__(self, s: StatusEffectInstance) -> None:
		pass

	@overload
	def getId(self) -> str:
		"""
		Since: 1.2.4 
		"""
		pass

	@overload
	def getStrength(self) -> int:
		"""
		Since: 1.2.4 
		"""
		pass

	@overload
	def getTime(self) -> int:
		"""
		Since: 1.2.4 
		"""
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .IScreen import IScreen
from .RenderCommon_Text import RenderCommon_Text
from .RenderCommon_Rect import RenderCommon_Rect
from .RenderCommon_Item import RenderCommon_Item
from .RenderCommon_Image import RenderCommon_Image
from .TextFieldWidgetHelper import TextFieldWidgetHelper
from .ButtonWidgetHelper import ButtonWidgetHelper
from .RenderCommon_RenderElement import RenderCommon_RenderElement
from .TextHelper import TextHelper
from .ItemStackHelper import ItemStackHelper
from .MethodWrapper import MethodWrapper

AbstractParentElement = TypeVar["net.minecraft.client.gui.AbstractParentElement"]
CallbackInfo = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfo"]
CallbackInfoReturnable = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable_java.lang.Boolean_"]
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
Style = TypeVar["net.minecraft.text.Style"]

class MixinScreen(IScreen, AbstractParentElement):
	width: int
	height: int

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def onClose(self) -> None:
		pass

	@overload
	def tick(self) -> None:
		pass

	@overload
	def shouldCloseOnEsc(self) -> bool:
		pass

	@overload
	def getWidth(self) -> int:
		pass

	@overload
	def getHeight(self) -> int:
		pass

	@overload
	def getTexts(self) -> List[RenderCommon_Text]:
		pass

	@overload
	def getRects(self) -> List[RenderCommon_Rect]:
		pass

	@overload
	def getItems(self) -> List[RenderCommon_Item]:
		pass

	@overload
	def getImages(self) -> List[RenderCommon_Image]:
		pass

	@overload
	def getTextFields(self) -> List[TextFieldWidgetHelper]:
		pass

	@overload
	def getButtonWidgets(self) -> List[ButtonWidgetHelper]:
		pass

	@overload
	def getElements(self) -> List[RenderCommon_RenderElement]:
		pass

	@overload
	def removeElement(self, e: RenderCommon_RenderElement) -> IScreen:
		pass

	@overload
	def reAddElement(self, e: RenderCommon_RenderElement) -> RenderCommon_RenderElement:
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, shadow: bool) -> RenderCommon_Text:
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool) -> RenderCommon_Text:
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, shadow: bool, scale: float, rotation: float) -> RenderCommon_Text:
		pass

	@overload
	def addText(self, text: str, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> RenderCommon_Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, shadow: bool) -> RenderCommon_Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool) -> RenderCommon_Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, shadow: bool, scale: float, rotation: float) -> RenderCommon_Text:
		pass

	@overload
	def addText(self, text: TextHelper, x: int, y: int, color: int, zIndex: int, shadow: bool, scale: float, rotation: float) -> RenderCommon_Text:
		pass

	@overload
	def removeText(self, t: RenderCommon_Text) -> IScreen:
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> RenderCommon_Image:
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int) -> RenderCommon_Image:
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
		"""
		Since: 1.4.0 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def addImage(self, x: int, y: int, width: int, height: int, zIndex: int, alpha: int, color: int, id: str, imageX: int, imageY: int, regionWidth: int, regionHeight: int, textureWidth: int, textureHeight: int, rotation: float) -> RenderCommon_Image:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def removeImage(self, i: RenderCommon_Image) -> IScreen:
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int) -> RenderCommon_Rect:
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int) -> RenderCommon_Rect:
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float) -> RenderCommon_Rect:
		pass

	@overload
	def addRect(self, x1: int, y1: int, x2: int, y2: int, color: int, alpha: int, rotation: float, zIndex: int) -> RenderCommon_Rect:
		pass

	@overload
	def removeRect(self, r: RenderCommon_Rect) -> IScreen:
		pass

	@overload
	def addItem(self, x: int, y: int, id: str) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str, overlay: bool) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, id: str, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, id: str, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper, overlay: bool) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper, overlay: bool) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, item: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		pass

	@overload
	def addItem(self, x: int, y: int, zIndex: int, item: ItemStackHelper, overlay: bool, scale: float, rotation: float) -> RenderCommon_Item:
		pass

	@overload
	def removeItem(self, i: RenderCommon_Item) -> IScreen:
		pass

	@overload
	def getScreenClassName(self) -> str:
		pass

	@overload
	def getTitleText(self) -> str:
		pass

	@overload
	def addButton(self, x: int, y: int, width: int, height: int, text: str, callback: MethodWrapper) -> ButtonWidgetHelper:
		pass

	@overload
	def addButton(self, x: int, y: int, width: int, height: int, zIndex: int, text: str, callback: MethodWrapper) -> ButtonWidgetHelper:
		pass

	@overload
	def removeButton(self, btn: ButtonWidgetHelper) -> IScreen:
		pass

	@overload
	def addTextInput(self, x: int, y: int, width: int, height: int, message: str, onChange: MethodWrapper) -> TextFieldWidgetHelper:
		pass

	@overload
	def addTextInput(self, x: int, y: int, width: int, height: int, zIndex: int, message: str, onChange: MethodWrapper) -> TextFieldWidgetHelper:
		pass

	@overload
	def removeTextInput(self, inp: TextFieldWidgetHelper) -> IScreen:
		pass

	@overload
	def soft$close(self) -> None:
		pass

	@overload
	def setOnMouseDown(self, onMouseDown: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnMouseDrag(self, onMouseDrag: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnMouseUp(self, onMouseUp: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnScroll(self, onScroll: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnKeyPressed(self, onKeyPressed: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnInit(self, onInit: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnFailInit(self, catchInit: MethodWrapper) -> IScreen:
		pass

	@overload
	def setOnClose(self, onClose: MethodWrapper) -> IScreen:
		pass

	@overload
	def reloadScreen(self) -> IScreen:
		pass

	@overload
	def onRenderInternal(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float, info: CallbackInfo) -> None:
		pass

	@overload
	def mouseClicked(self, mouseX: float, mouseY: float, button: int) -> bool:
		pass

	@overload
	def mouseDragged(self, mouseX: float, mouseY: float, button: int, deltaX: float, deltaY: float) -> bool:
		pass

	@overload
	def mouseReleased(self, mouseX: float, mouseY: float, button: int) -> bool:
		pass

	@overload
	def keyPressed(self, keyCode: int, scanCode: int, modifiers: int, info: CallbackInfoReturnable) -> None:
		pass

	@overload
	def mouseScrolled(self, mouseX: float, mouseY: float, amount: float) -> bool:
		pass

	@overload
	def handleCustomClickEvent(self, style: Style, cir: CallbackInfoReturnable) -> None:
		pass

	@overload
	def getOnClose(self) -> MethodWrapper:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .EntityHelper import EntityHelper

Entity = TypeVar["net.minecraft.entity.Entity"]
Entity_RemovalReason = TypeVar["net.minecraft.entity.Entity.RemovalReason"]

class EventEntityUnload(BaseEvent):
	entity: EntityHelper
	reason: str

	@overload
	def __init__(self, e: Entity, reason: Entity_RemovalReason) -> None:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper

SuggestionsBuilder = TypeVar["com.mojang.brigadier.suggestion.SuggestionsBuilder"]

class SuggestionsBuilderHelper(BaseHelper):
	"""
	Since: 1.6.5 
	"""

	@overload
	def __init__(self, base: SuggestionsBuilder) -> None:
		pass

	@overload
	def getInput(self) -> str:
		pass

	@overload
	def getStart(self) -> int:
		pass

	@overload
	def getRemaining(self) -> str:
		pass

	@overload
	def getRemainingLowerCase(self) -> str:
		pass

	@overload
	def suggest(self, suggestion: str) -> "SuggestionsBuilderHelper":
		pass

	@overload
	def suggest(self, value: int) -> "SuggestionsBuilderHelper":
		pass

	@overload
	def suggestWithTooltip(self, suggestion: str, tooltip: TextHelper) -> "SuggestionsBuilderHelper":
		pass

	@overload
	def suggestWithTooltip(self, value: int, tooltip: TextHelper) -> "SuggestionsBuilderHelper":
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper
from .NBTElementHelper import NBTElementHelper
from .BlockStateHelper import BlockStateHelper
from .BlockHelper import BlockHelper
from .BlockPosHelper import BlockPosHelper

BlockState = TypeVar["net.minecraft.block.BlockState"]
Block = TypeVar["net.minecraft.block.Block"]
BlockPos = TypeVar["net.minecraft.util.math.BlockPos"]
BlockEntity = TypeVar["net.minecraft.block.entity.BlockEntity"]

class BlockDataHelper(BaseHelper):
	"""
	"""

	@overload
	def __init__(self, b: BlockState, e: BlockEntity, bp: BlockPos) -> None:
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.1.7 

		Returns:
			the 'x' value of the block. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.1.7 

		Returns:
			the 'y' value of the block. 
		"""
		pass

	@overload
	def getZ(self) -> int:
		"""
		Since: 1.1.7 

		Returns:
			the 'z' value of the block. 
		"""
		pass

	@overload
	def getId(self) -> str:
		"""

		Returns:
			the item ID of the block. 
		"""
		pass

	@overload
	def getName(self) -> TextHelper:
		"""

		Returns:
			the translated name of the block. (was string before 1.6.5) 
		"""
		pass

	@overload
	def getNBT(self) -> NBTElementHelper:
		"""
		Since: 1.5.1, used to be a Map String , String 
		"""
		pass

	@overload
	def getBlockStateHelper(self) -> BlockStateHelper:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getBlockHelper(self) -> BlockHelper:
		"""
		Since: 1.6.5 
		"""
		pass

	@overload
	def getBlockState(self) -> Mapping[str, str]:
		"""
		Since: 1.1.7 

		Returns:
			block state data as a Map . 
		"""
		pass

	@overload
	def getBlockPos(self) -> BlockPosHelper:
		"""
		Since: 1.2.7 

		Returns:
			the block pos. 
		"""
		pass

	@overload
	def getRawBlock(self) -> Block:
		pass

	@overload
	def getRawBlockState(self) -> BlockState:
		pass

	@overload
	def getRawBlockEntity(self) -> BlockEntity:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from .EntityHelper import EntityHelper
from .ItemStackHelper import ItemStackHelper

ItemEntity = TypeVar["net.minecraft.entity.ItemEntity"]

class ItemEntityHelper(EntityHelper):

	@overload
	def __init__(self, e: ItemEntity) -> None:
		pass

	@overload
	def getContainedItemStack(self) -> ItemStackHelper:
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Generic
from .IPalettedContainerData import IPalettedContainerData

Palette = TypeVar["net.minecraft.world.chunk.Palette_T_"]
T = TypeVar("T")
PaletteStorage = TypeVar["net.minecraft.util.collection.PaletteStorage"]

class MixinPalettedContainerData(IPalettedContainerData, Generic[T]):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getStorage(self) -> PaletteStorage:
		pass

	@overload
	def jsmacros_getPalette(self) -> Palette:
		pass

	pass





from typing import overload
from typing import TypeVar

NarrationMessageBuilder = TypeVar["net.minecraft.client.gui.screen.narration.NarrationMessageBuilder"]
Consumer = TypeVar["java.util.function.Consumer_java.lang.Double_"]
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
ClickableWidget = TypeVar["net.minecraft.client.gui.widget.ClickableWidget"]

class Scrollbar(ClickableWidget):

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, color: int, borderColor: int, hilightColor: int, scrollPages: float, onChange: Consumer) -> None:
		pass

	@overload
	def setPos(self, x: int, y: int, width: int, height: int) -> "Scrollbar":
		pass

	@overload
	def setScrollPages(self, scrollPages: float) -> None:
		pass

	@overload
	def scrollToPercent(self, percent: float) -> None:
		pass

	@overload
	def onClick(self, mouseX: float, mouseY: float) -> None:
		pass

	@overload
	def onChange(self) -> None:
		pass

	@overload
	def mouseDragged(self, mouseX: float, mouseY: float, button: int, deltaX: float, deltaY: float) -> bool:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	@overload
	def appendNarrations(self, builder: NarrationMessageBuilder) -> None:
		pass

	pass





from typing import overload
from .TextHelper import TextHelper
from .ItemStackHelper import ItemStackHelper
from .EntityHelper import EntityHelper
from .MethodWrapper import MethodWrapper
from .StyleHelper import StyleHelper


class TextBuilder:
	"""usage: 'builder.append("hello,").withColor(0xc).append(" World!").withColor(0x6)'\n
	Since: 1.3.0 
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def append(self, text: object) -> "TextBuilder":
		"""move on to next section and set it's text.\n
		Since: 1.3.0 

		Args:
			text: a String , TextHelper or TextBuilder 
		"""
		pass

	@overload
	def withColor(self, color: int) -> "TextBuilder":
		"""set current section's color by color code as hex, like '0x6' for gold
and '0xc' for red.\n
		Since: 1.3.0 

		Args:
			color: 
		"""
		pass

	@overload
	def withColor(self, r: int, g: int, b: int) -> "TextBuilder":
		"""Add text with custom colors.\n
		Since: 1.3.1 

		Args:
			r: red '0-255' 
			b: blue '0-255' 
			g: green '0-255' 
		"""
		pass

	@overload
	def withFormatting(self, underline: bool, bold: bool, italic: bool, strikethrough: bool, magic: bool) -> "TextBuilder":
		"""set other formatting options for the current section\n
		Since: 1.3.0 

		Args:
			magic: 
			underline: 
			bold: 
			strikethrough: 
			italic: 
		"""
		pass

	@overload
	def withShowTextHover(self, text: TextHelper) -> "TextBuilder":
		"""set current section's hover event to show text\n
		Since: 1.3.0 

		Args:
			text: 
		"""
		pass

	@overload
	def withShowItemHover(self, item: ItemStackHelper) -> "TextBuilder":
		"""set current section's hover event to show an item\n
		Since: 1.3.0 

		Args:
			item: 
		"""
		pass

	@overload
	def withShowEntityHover(self, entity: EntityHelper) -> "TextBuilder":
		"""set current section's hover event to show an entity\n
		Since: 1.3.0 

		Args:
			entity: 
		"""
		pass

	@overload
	def withCustomClickEvent(self, action: MethodWrapper) -> "TextBuilder":
		"""custom click event.\n
		Since: 1.3.0 

		Args:
			action: 
		"""
		pass

	@overload
	def withClickEvent(self, action: str, value: str) -> "TextBuilder":
		"""normal click events like: 'open_url' , 'open_file' , 'run_command' , 'suggest_command' , 'change_page' , and 'copy_to_clipboard'\n
		Since: 1.3.0 

		Args:
			action: 
			value: 
		"""
		pass

	@overload
	def withStyle(self, style: StyleHelper) -> "TextBuilder":
		pass

	@overload
	def build(self) -> TextHelper:
		"""Build to a TextHelper\n
		Since: 1.3.0 
		"""
		pass

	pass





from typing import overload
from .BaseEvent import BaseEvent
from .BlockDataHelper import BlockDataHelper


class EventAttackBlock(BaseEvent):
	block: BlockDataHelper
	side: int

	@overload
	def __init__(self, block: BlockDataHelper, side: int) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseEvent import BaseEvent
from .BaseHelper import BaseHelper

CommandContext = TypeVar["com.mojang.brigadier.context.CommandContext__"]
StringRange = TypeVar["com.mojang.brigadier.context.StringRange"]

class CommandContextHelper(BaseEvent, BaseHelper):
	"""
	Since: 1.4.2 
	"""

	@overload
	def __init__(self, base: CommandContext) -> None:
		pass

	@overload
	def getArg(self, name: str) -> object:
		"""
		Since: 1.4.2 

		Args:
			name: 
		"""
		pass

	@overload
	def getChild(self) -> "CommandContextHelper":
		pass

	@overload
	def getRange(self) -> StringRange:
		pass

	@overload
	def getInput(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping

MutableText = TypeVar["net.minecraft.text.MutableText"]
AbsVisitor = TypeVar["io.noties.prism4j.AbsVisitor"]
Style = TypeVar["net.minecraft.text.Style"]

class TextStyleCompiler(AbsVisitor):

	@overload
	def __init__(self, defaultStyle: Style, themeData: Mapping[str, List[float]]) -> None:
		pass

	@overload
	def getResult(self) -> List[MutableText]:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Mapping
from .BaseHelper import BaseHelper

GameOptions = TypeVar["net.minecraft.client.option.GameOptions"]

class OptionsHelper(BaseHelper):
	"""
	Since: 1.1.7 
	"""

	@overload
	def __init__(self, options: GameOptions) -> None:
		pass

	@overload
	def getCloudMode(self) -> int:
		"""
		Since: 1.1.7 

		Returns:
			0: off, 2: fancy 
		"""
		pass

	@overload
	def setCloudMode(self, mode: int) -> "OptionsHelper":
		"""
		Since: 1.1.7 

		Args:
			mode: 0: off, 2: fancy 
		"""
		pass

	@overload
	def getGraphicsMode(self) -> int:
		"""
		Since: 1.1.7 
		"""
		pass

	@overload
	def setGraphicsMode(self, mode: int) -> "OptionsHelper":
		"""
		Since: 1.1.7 

		Args:
			mode: 0: fast, 2: fabulous 
		"""
		pass

	@overload
	def getResourcePacks(self) -> List[str]:
		"""
		Since: 1.1.7 

		Returns:
			list of names of resource packs. 
		"""
		pass

	@overload
	def getEnabledResourcePacks(self) -> List[str]:
		"""
		Since: 1.2.0 

		Returns:
			list of names of enabled resource packs. 
		"""
		pass

	@overload
	def setEnabledResourcePacks(self, enabled: List[str]) -> "OptionsHelper":
		"""Set the enabled resource packs to the provided list.\n
		Since: 1.2.0 

		Args:
			enabled: 
		"""
		pass

	@overload
	def isRightHanded(self) -> bool:
		"""
		Since: 1.1.7 
		"""
		pass

	@overload
	def setRightHanded(self, val: bool) -> None:
		"""
		Since: 1.1.7 

		Args:
			val: 
		"""
		pass

	@overload
	def getFov(self) -> float:
		"""
		Since: 1.1.7 
		"""
		pass

	@overload
	def setFov(self, fov: int) -> "OptionsHelper":
		"""
		Since: 1.1.7 

		Args:
			fov: (int since 1.7.0) 
		"""
		pass

	@overload
	def getRenderDistance(self) -> int:
		"""
		Since: 1.1.7 
		"""
		pass

	@overload
	def setRenderDistance(self, d: int) -> None:
		"""
		Since: 1.1.7 

		Args:
			d: 
		"""
		pass

	@overload
	def getWidth(self) -> int:
		"""
		Since: 1.2.6 
		"""
		pass

	@overload
	def getHeight(self) -> int:
		"""
		Since: 1.2.6 
		"""
		pass

	@overload
	def setWidth(self, w: int) -> None:
		"""
		Since: 1.2.6 

		Args:
			w: 
		"""
		pass

	@overload
	def setHeight(self, h: int) -> None:
		"""
		Since: 1.2.6 

		Args:
			h: 
		"""
		pass

	@overload
	def setSize(self, w: int, h: int) -> None:
		"""
		Since: 1.2.6 

		Args:
			w: 
			h: 
		"""
		pass

	@overload
	def getGamma(self) -> float:
		"""
		Since: 1.3.0
normal values for gamam are between '0' and '1' 
		"""
		pass

	@overload
	def setGamma(self, gamma: float) -> None:
		"""
		Since: 1.3.0
normal values for gamma are between '0' and '1' 
		"""
		pass

	@overload
	def setVolume(self, vol: float) -> None:
		"""
		Since: 1.3.1 

		Args:
			vol: 
		"""
		pass

	@overload
	def setVolume(self, category: str, volume: float) -> None:
		"""set volume by category.\n
		Since: 1.3.1 

		Args:
			volume: 
			category: 
		"""
		pass

	@overload
	def getVolumes(self) -> Mapping[str, Float]:
		"""
		Since: 1.3.1 
		"""
		pass

	@overload
	def setGuiScale(self, scale: int) -> None:
		"""sets gui scale, '0' for auto.\n
		Since: 1.3.1 

		Args:
			scale: 
		"""
		pass

	@overload
	def getGuiScale(self) -> int:
		"""
		Since: 1.3.1 

		Returns:
			gui scale, '0' for auto. 
		"""
		pass

	@overload
	def getVolume(self, category: str) -> float:
		"""
		Since: 1.3.1 

		Args:
			category: 
		"""
		pass

	@overload
	def getSmoothCamera(self) -> bool:
		"""
		Since: 1.5.0 
		"""
		pass

	@overload
	def setSmoothCamera(self, val: bool) -> None:
		"""
		Since: 1.5.0 

		Args:
			val: 
		"""
		pass

	@overload
	def getCameraMode(self) -> int:
		"""
		Since: 1.5.0 

		Returns:
			0 for 1st person, 2 for in front. 
		"""
		pass

	@overload
	def setCameraMode(self, mode: int) -> None:
		"""
		Since: 1.5.0 

		Args:
			mode: 0: first, 2: front 
		"""
		pass

	pass





from typing import TypeVar

from .EventContainer import EventContainer
from .BaseEvent import BaseEvent
from .MixinSignEditScreen import MixinSignEditScreen
from .MixinHungerManager import MixinHungerManager
from .MixinRecipeBookWidget import MixinRecipeBookWidget
from .MixinFontManager import MixinFontManager
from .MixinChunkSelection import MixinChunkSelection
from .IMixinEntity import IMixinEntity
from .MixinLivingEntity import MixinLivingEntity
from .MixinMinecraftClient import MixinMinecraftClient
from .MixinPackedIntegerArray import MixinPackedIntegerArray
from .MixinClientPlayerEntity import MixinClientPlayerEntity
from .MixinClientPlayNetworkHandler import MixinClientPlayNetworkHandler
from .MixinMerchantEntity import MixinMerchantEntity
from .MixinDisconnectedScreen import MixinDisconnectedScreen
from .MixinSplashOverlay import MixinSplashOverlay
from .MixinTrueTypeFont import MixinTrueTypeFont
from .MixinClientPlayerInteractionManager import MixinClientPlayerInteractionManager
from .MixinHorseScreen import MixinHorseScreen
from .MixinCreativeInventoryScreen import MixinCreativeInventoryScreen
from .MixinPalettedContainer import MixinPalettedContainer
from .MixinChatHud import MixinChatHud
from .MixinLoomScreen import MixinLoomScreen
from .MixinHandledScreen import MixinHandledScreen
from .MixinItemCooldownManager import MixinItemCooldownManager
from .MixinSimpleOption import MixinSimpleOption
from .MixinClientWorld import MixinClientWorld
from .MixinSoundSystem import MixinSoundSystem
from .MixinTranslationStorage import MixinTranslationStorage
from .MixinPlayerListHud import MixinPlayerListHud
from .MixinBeaconScreen import MixinBeaconScreen
from .MixinItemCooldownEntry import MixinItemCooldownEntry
from .MixinFontStorage import MixinFontStorage
from .MixinBossBarHud import MixinBossBarHud
from .MixinEntity import MixinEntity
from .MixinPlayerEntity import MixinPlayerEntity
from .MixinRecipeBookResults import MixinRecipeBookResults
from .MixinMerchantScreen import MixinMerchantScreen
from .MixinStyleSerializer import MixinStyleSerializer
from .MixinScreen import MixinScreen
from .MixinPalettedContainerData import MixinPalettedContainerData

File = TypeVar["java.io.File"]




from typing import overload
from typing import List
from typing import TypeVar
from typing import Generic
from .EntityHelper import EntityHelper
from .StatusEffectHelper import StatusEffectHelper
from .ItemStackHelper import ItemStackHelper

T = TypeVar("T")

class LivingEntityHelper(Generic[T], EntityHelper):

	@overload
	def __init__(self, e: T) -> None:
		pass

	@overload
	def getStatusEffects(self) -> List[StatusEffectHelper]:
		"""
		Since: 1.2.7 

		Returns:
			entity status effects. 
		"""
		pass

	@overload
	def getMainHand(self) -> ItemStackHelper:
		"""
		Since: 1.2.7 

		Returns:
			the item in the entity's main hand. 
		"""
		pass

	@overload
	def getOffHand(self) -> ItemStackHelper:
		"""
		Since: 1.2.7 

		Returns:
			the item in the entity's off hand. 
		"""
		pass

	@overload
	def getHeadArmor(self) -> ItemStackHelper:
		"""
		Since: 1.2.7 

		Returns:
			the item in the entity's head armor slot. 
		"""
		pass

	@overload
	def getChestArmor(self) -> ItemStackHelper:
		"""
		Since: 1.2.7 

		Returns:
			the item in the entity's chest armor slot. 
		"""
		pass

	@overload
	def getLegArmor(self) -> ItemStackHelper:
		"""
		Since: 1.2.7 

		Returns:
			the item in the entity's leg armor slot. 
		"""
		pass

	@overload
	def getFootArmor(self) -> ItemStackHelper:
		"""
		Since: 1.2.7 

		Returns:
			the item in the entity's foot armor slot. 
		"""
		pass

	@overload
	def getHealth(self) -> float:
		"""
		Since: 1.3.1 

		Returns:
			entity's health 
		"""
		pass

	@overload
	def getMaxHealth(self) -> float:
		"""
		Since: 1.6.5 

		Returns:
			entity's max health 
		"""
		pass

	@overload
	def isSleeping(self) -> bool:
		"""
		Since: 1.2.7 

		Returns:
			if the entity is in a bed. 
		"""
		pass

	@overload
	def isFallFlying(self) -> bool:
		"""
		Since: 1.5.0 

		Returns:
			if the entity has elytra deployed 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .IBeaconScreen import IBeaconScreen

StatusEffect = TypeVar["net.minecraft.entity.effect.StatusEffect"]

class MixinBeaconScreen(IBeaconScreen):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getPrimaryEffect(self) -> StatusEffect:
		pass

	@overload
	def jsmacros_setPrimaryEffect(self, effect: StatusEffect) -> None:
		pass

	@overload
	def jsmacros_getSecondaryEffect(self) -> StatusEffect:
		pass

	@overload
	def jsmacros_setSecondaryEffect(self, effect: StatusEffect) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .IMixinEntity import IMixinEntity

CallbackInfoReturnable = TypeVar["org.spongepowered.asm.mixin.injection.callback.CallbackInfoReturnable_java.lang.Boolean_"]

class MixinEntity(IMixinEntity):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_setGlowingColor(self, glowingColor: int) -> None:
		pass

	@overload
	def jsmacros_resetColor(self) -> None:
		pass

	@overload
	def getTeamColorValue(self, ci: CallbackInfoReturnable) -> None:
		pass

	@overload
	def jsmacros_setForceGlowing(self, glowing: int) -> None:
		pass

	@overload
	def isGlowing(self, cir: CallbackInfoReturnable) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .IRecipeBookWidget import IRecipeBookWidget

RecipeBookResults = TypeVar["net.minecraft.client.gui.screen.recipebook.RecipeBookResults"]

class MixinRecipeBookWidget(IRecipeBookWidget):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_getResults(self) -> RecipeBookResults:
		pass

	@overload
	def jsmacros_isSearching(self) -> bool:
		pass

	@overload
	def jsmacros_refreshResultList(self) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar

Prism4j_Grammar = TypeVar["io.noties.prism4j.Prism4j.Grammar"]

class Prism_clike:
	"""This class is from Prism4j under the Apache-2.0 license updated to match upstream
	"""

	@overload
	def create(self, prism4j: Prism4j) -> Prism4j_Grammar:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Mapping
from .IBossBarHud import IBossBarHud

ClientBossBar = TypeVar["net.minecraft.client.gui.hud.ClientBossBar"]
UUID = TypeVar["java.util.UUID"]

class MixinBossBarHud(IBossBarHud):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def jsmacros_GetBossBars(self) -> Mapping[UUID, ClientBossBar]:
		pass

	pass





from typing import overload
from typing import TypeVar

Palette = TypeVar["net.minecraft.world.chunk.Palette_T_"]
PaletteStorage = TypeVar["net.minecraft.util.collection.PaletteStorage"]

class IPalettedContainerData:

	@overload
	def jsmacros_getStorage(self) -> PaletteStorage:
		pass

	@overload
	def jsmacros_getPalette(self) -> Palette:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper

PlayerAbilities = TypeVar["net.minecraft.entity.player.PlayerAbilities"]

class PlayerAbilitiesHelper(BaseHelper):
	"""
	Since: 1.0.3 
	"""

	@overload
	def __init__(self, a: PlayerAbilities) -> None:
		pass

	@overload
	def getInvulnerable(self) -> bool:
		"""
		Since: 1.0.3 

		Returns:
			whether the player can be damaged. 
		"""
		pass

	@overload
	def getFlying(self) -> bool:
		"""
		Since: 1.0.3 

		Returns:
			if the player is currently flying. 
		"""
		pass

	@overload
	def getAllowFlying(self) -> bool:
		"""
		Since: 1.0.3 

		Returns:
			if the player is allowed to fly. 
		"""
		pass

	@overload
	def getCreativeMode(self) -> bool:
		"""
		Since: 1.0.3 

		Returns:
			if the player is in creative. 
		"""
		pass

	@overload
	def setFlying(self, b: bool) -> "PlayerAbilitiesHelper":
		"""set the player flying state.\n
		Since: 1.0.3 

		Args:
			b: 
		"""
		pass

	@overload
	def setAllowFlying(self, b: bool) -> "PlayerAbilitiesHelper":
		"""set the player allow flying state.\n
		Since: 1.0.3 

		Args:
			b: 
		"""
		pass

	@overload
	def getFlySpeed(self) -> float:
		"""
		Since: 1.0.3 

		Returns:
			the player fly speed multiplier. 
		"""
		pass

	@overload
	def setFlySpeed(self, flySpeed: float) -> "PlayerAbilitiesHelper":
		"""set the player fly speed multiplier.\n
		Since: 1.0.3 

		Args:
			flySpeed: 
		"""
		pass

	pass





from typing import overload
from typing import List
from .BaseLibrary import BaseLibrary
from .Inventory import Inventory
from .ClientPlayerEntityHelper import ClientPlayerEntityHelper
from .BlockDataHelper import BlockDataHelper
from .EntityHelper import EntityHelper
from .MethodWrapper import MethodWrapper
from .PlayerInput import PlayerInput
from .PositionCommon_Pos3D import PositionCommon_Pos3D


class FPlayer(BaseLibrary):
	"""Functions for getting and modifying the player's state.

An instance of this class is passed to scripts as the 'Player' variable.
	"""

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def openInventory(self) -> Inventory:
		"""

		Returns:
			the Inventory handler 
		"""
		pass

	@overload
	def getPlayer(self) -> ClientPlayerEntityHelper:
		"""
		Since: 1.0.3 

		Returns:
			the player entity wrapper. 
		"""
		pass

	@overload
	def getGameMode(self) -> str:
		"""
		Since: 1.0.9 

		Returns:
			the player's current gamemode. 
		"""
		pass

	@overload
	def rayTraceBlock(self, distance: float, fluid: bool) -> BlockDataHelper:
		"""
		Since: 1.0.5 

		Args:
			distance: 
			fluid: 

		Returns:
			the block/liquid the player is currently looking at. 
		"""
		pass

	@overload
	def rayTraceEntity(self) -> EntityHelper:
		"""
		Since: 1.0.5 

		Returns:
			the entity the player is currently looking at. 
		"""
		pass

	@overload
	def writeSign(self, l1: str, l2: str, l3: str, l4: str) -> bool:
		"""Write to a sign screen if a sign screen is currently open.\n
		Since: 1.2.2 

		Args:
			l1: 
			l2: 
			l3: 
			l4: 

		Returns:
			of success. 
		"""
		pass

	@overload
	def takeScreenshot(self, folder: str, callback: MethodWrapper) -> None:
		"""
		Since: 1.2.6 

		Args:
			folder: 
			callback: calls your method as a Consumer TextHelper 
		"""
		pass

	@overload
	def takeScreenshot(self, folder: str, file: str, callback: MethodWrapper) -> None:
		"""Take a screenshot and save to a file. 
'file' is the optional one, typescript doesn't like it not being the last one that's optional\n
		Since: 1.2.6 

		Args:
			folder: 
			file: 
			callback: calls your method as a Consumer TextHelper 
		"""
		pass

	@overload
	def createPlayerInput(self) -> PlayerInput:
		"""Creates a new PlayerInput object.\n
		Since: 1.4.0 
		"""
		pass

	@overload
	def createPlayerInput(self, movementForward: float, movementSideways: float, yaw: float) -> PlayerInput:
		"""Creates a new PlayerInput object.\n
		Since: 1.4.0 
		"""
		pass

	@overload
	def createPlayerInput(self, movementForward: float, yaw: float, jumping: bool, sprinting: bool) -> PlayerInput:
		"""Creates a new PlayerInput object.\n
		Since: 1.4.0 
		"""
		pass

	@overload
	def createPlayerInput(self, movementForward: float, movementSideways: float, yaw: float, pitch: float, jumping: bool, sneaking: bool, sprinting: bool) -> PlayerInput:
		"""Creates a new PlayerInput object.\n
		Since: 1.4.0 

		Args:
			movementForward: 1 = forward input (W); 0 = no input; -1 = backward input (S) 
			sprinting: sprint input 
			jumping: jump input 
			sneaking: sneak input 
			pitch: pitch of the player 
			yaw: yaw of the player 
			movementSideways: 1 = left input (A); 0 = no input; -1 = right input (D) 
		"""
		pass

	@overload
	def createPlayerInputsFromCsv(self, csv: str) -> List[PlayerInput]:
		"""Parses each row of CSV string into a 'PlayerInput' .
The capitalization of the header matters. About the columns:  
-  'movementForward' and 'movementSideways' as a number  
- 'yaw' and 'pitch' as an absolute number  
- 'jumping' , 'sneaking' and 'sprinting' have to be boolean   
The separation must be a "," it's a csv...(but spaces don't matter) Quoted values don't work\n
		Since: 1.4.0 

		Args:
			csv: CSV string to be parsed 
		"""
		pass

	@overload
	def createPlayerInputsFromJson(self, json: str) -> PlayerInput:
		"""Parses a JSON string into a 'PlayerInput' Object
For details see 'PlayerInput.fromCsv()' , on what has to be present. Capitalization of the keys matters.\n
		Since: 1.4.0 

		Args:
			json: JSON string to be parsed 

		Returns:
			The JSON parsed into a 'PlayerInput' 
		"""
		pass

	@overload
	def getCurrentPlayerInput(self) -> PlayerInput:
		"""Creates a new 'PlayerInput' object with the current inputs of the player.\n
		Since: 1.4.0 
		"""
		pass

	@overload
	def addInput(self, input: PlayerInput) -> None:
		"""Adds a new 'PlayerInput' to 'MovementQueue' to be executed\n
		Since: 1.4.0 

		Args:
			input: the PlayerInput to be executed 
		"""
		pass

	@overload
	def addInputs(self, inputs: List[PlayerInput]) -> None:
		"""Adds multiple new 'PlayerInput' to 'MovementQueue' to be executed\n
		Since: 1.4.0 

		Args:
			inputs: the PlayerInputs to be executed 
		"""
		pass

	@overload
	def clearInputs(self) -> None:
		"""Clears all inputs in the 'MovementQueue'\n
		Since: 1.4.0 
		"""
		pass

	@overload
	def setDrawPredictions(self, val: bool) -> None:
		pass

	@overload
	def predictInput(self, input: PlayerInput) -> PositionCommon_Pos3D:
		"""Predicts where one tick with a 'PlayerInput' as input would lead to.\n
		Since: 1.4.0 

		Args:
			input: the PlayerInput for the prediction 

		Returns:
			the position after the input 
		"""
		pass

	@overload
	def predictInput(self, input: PlayerInput, draw: bool) -> PositionCommon_Pos3D:
		"""Predicts where one tick with a 'PlayerInput' as input would lead to.\n
		Since: 1.4.0 

		Args:
			input: the PlayerInput for the prediction 
			draw: whether to visualize the result or not 

		Returns:
			the position after the input 
		"""
		pass

	@overload
	def predictInputs(self, inputs: List[PlayerInput]) -> List[PositionCommon_Pos3D]:
		"""Predicts where each 'PlayerInput' executed in a row would lead
without drawing it.\n
		Since: 1.4.0 

		Args:
			inputs: the PlayerInputs for each tick for the prediction 

		Returns:
			the position after each input 
		"""
		pass

	@overload
	def isBreakingBlock(self) -> bool:
		"""
		Since: 1.8.0 
		"""
		pass

	@overload
	def predictInputs(self, inputs: List[PlayerInput], draw: bool) -> List[PositionCommon_Pos3D]:
		"""Predicts where each 'PlayerInput' executed in a row would lead\n
		Since: 1.4.0 

		Args:
			inputs: the PlayerInputs for each tick for the prediction 
			draw: whether to visualize the result or not 

		Returns:
			the position after each input 
		"""
		pass

	@overload
	def moveForward(self, yaw: float) -> None:
		"""Adds a forward movement with a relative yaw value to the MovementQueue.\n
		Since: 1.4.0 

		Args:
			yaw: the relative yaw for the player 
		"""
		pass

	@overload
	def moveBackward(self, yaw: float) -> None:
		"""Adds a backward movement with a relative yaw value to the MovementQueue.\n
		Since: 1.4.0 

		Args:
			yaw: the relative yaw for the player 
		"""
		pass

	@overload
	def moveStrafeLeft(self, yaw: float) -> None:
		"""Adds sideways movement with a relative yaw value to the MovementQueue.\n
		Since: 1.4.2 

		Args:
			yaw: the relative yaw for the player 
		"""
		pass

	@overload
	def moveStrafeRight(self, yaw: float) -> None:
		"""Adds sideways movement with a relative yaw value to the MovementQueue.\n
		Since: 1.4.2 

		Args:
			yaw: the relative yaw for the player 
		"""
		pass

	pass





from typing import overload
from typing import TypeVar
from .ScriptTrigger import ScriptTrigger

Comparator = TypeVar["java.util.Comparator_xyz.wagyourtail.jsmacros.core.config.ScriptTrigger_"]

class Sorting_SortByEnabled(Comparator):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def compare(self, a: ScriptTrigger, b: ScriptTrigger) -> int:
		pass

	pass





from typing import overload
from typing import TypeVar
from typing import Set

Identifier = TypeVar["net.minecraft.util.Identifier"]

class IFontManager:

	@overload
	def jsmacros_getFontList(self) -> Set[Identifier]:
		pass

	pass





from typing import overload
from typing import TypeVar

BossBar_Style = TypeVar["net.minecraft.entity.boss.BossBar.Style"]
Text = TypeVar["net.minecraft.text.Text"]
BossBarS2CPacket_Consumer = TypeVar["net.minecraft.network.packet.s2c.play.BossBarS2CPacket.Consumer"]
UUID = TypeVar["java.util.UUID"]
BossBar_Color = TypeVar["net.minecraft.entity.boss.BossBar.Color"]

class BossBarConsumer(BossBarS2CPacket_Consumer):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def add(self, uuid: UUID, name: Text, percent: float, color: BossBar_Color, style: BossBar_Style, darkenSky: bool, dragonMusic: bool, thickenFog: bool) -> None:
		pass

	@overload
	def remove(self, uuid: UUID) -> None:
		pass

	@overload
	def updateProgress(self, uuid: UUID, percent: float) -> None:
		pass

	@overload
	def updateName(self, uuid: UUID, name: Text) -> None:
		pass

	@overload
	def updateStyle(self, id: UUID, color: BossBar_Color, style: BossBar_Style) -> None:
		pass

	@overload
	def updateProperties(self, uuid: UUID, darkenSky: bool, dragonMusic: bool, thickenFog: bool) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper
from .TextHelper import TextHelper

ChatHudLine = TypeVar["net.minecraft.client.gui.hud.ChatHudLine"]
ChatHud = TypeVar["net.minecraft.client.gui.hud.ChatHud"]

class ChatHudLineHelper(BaseHelper):

	@overload
	def __init__(self, base: ChatHudLine, hud: ChatHud) -> None:
		pass

	@overload
	def getText(self) -> TextHelper:
		pass

	@overload
	def getCreationTick(self) -> int:
		pass

	@overload
	def deleteById(self) -> None:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .MultiElementContainer import MultiElementContainer
from .IOverlayParent import IOverlayParent

Consumer = TypeVar["java.util.function.Consumer_java.lang.Integer_"]
MatrixStack = TypeVar["net.minecraft.client.util.math.MatrixStack"]
Text = TypeVar["net.minecraft.text.Text"]
TextRenderer = TypeVar["net.minecraft.client.font.TextRenderer"]

class ListContainer(MultiElementContainer):
	onSelect: Consumer

	@overload
	def __init__(self, x: int, y: int, width: int, height: int, textRenderer: TextRenderer, list: List[Text], parent: IOverlayParent, onSelect: Consumer) -> None:
		pass

	@overload
	def init(self) -> None:
		pass

	@overload
	def addItem(self, name: Text) -> None:
		pass

	@overload
	def setSelected(self, index: int) -> None:
		pass

	@overload
	def onScrollbar(self, page: float) -> None:
		pass

	@overload
	def render(self, matrices: MatrixStack, mouseX: int, mouseY: int, delta: float) -> None:
		pass

	pass





from typing import overload
from typing import TypeVar
from .BaseHelper import BaseHelper

BlockPos = TypeVar["net.minecraft.util.math.BlockPos"]

class BlockPosHelper(BaseHelper):
	"""
	Since: 1.2.6 
	"""

	@overload
	def __init__(self, b: BlockPos) -> None:
		pass

	@overload
	def __init__(self, x: int, y: int, z: int) -> None:
		pass

	@overload
	def getX(self) -> int:
		"""
		Since: 1.2.6 

		Returns:
			the 'x' value of the block. 
		"""
		pass

	@overload
	def getY(self) -> int:
		"""
		Since: 1.2.6 

		Returns:
			the 'y' value of the block. 
		"""
		pass

	@overload
	def getZ(self) -> int:
		"""
		Since: 1.2.6 

		Returns:
			the 'z' value of the block. 
		"""
		pass

	@overload
	def up(self) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Returns:
			the block above. 
		"""
		pass

	@overload
	def up(self, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: 

		Returns:
			the block n-th block above. 
		"""
		pass

	@overload
	def down(self) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Returns:
			the block below. 
		"""
		pass

	@overload
	def down(self, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: 

		Returns:
			the block n-th block below. 
		"""
		pass

	@overload
	def north(self) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Returns:
			the block to the north. 
		"""
		pass

	@overload
	def north(self, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: 

		Returns:
			the n-th block to the north. 
		"""
		pass

	@overload
	def south(self) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Returns:
			the block to the south. 
		"""
		pass

	@overload
	def south(self, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: 

		Returns:
			the n-th block to the south. 
		"""
		pass

	@overload
	def east(self) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Returns:
			the block to the east. 
		"""
		pass

	@overload
	def east(self, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: 

		Returns:
			the n-th block to the east. 
		"""
		pass

	@overload
	def west(self) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Returns:
			the block to the west. 
		"""
		pass

	@overload
	def west(self, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: 

		Returns:
			the n-th block to the west. 
		"""
		pass

	@overload
	def offset(self, direction: str) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 

		Returns:
			the block offset by the given direction. 
		"""
		pass

	@overload
	def offset(self, direction: str, distance: int) -> "BlockPosHelper":
		"""
		Since: 1.6.5 

		Args:
			distance: 
			direction: 0-5 in order: [DOWN, UP, NORTH, SOUTH, WEST, EAST]; 

		Returns:
			the n-th block offset by the given direction. 
		"""
		pass

	@overload
	def toString(self) -> str:
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from .PlayerInput import PlayerInput

LivingEntity = TypeVar["net.minecraft.entity.LivingEntity"]
Iterable = TypeVar["java.lang.Iterable_net.minecraft.item.ItemStack_"]
EquipmentSlot = TypeVar["net.minecraft.entity.EquipmentSlot"]
Box = TypeVar["net.minecraft.util.math.Box"]
ClientPlayerEntity = TypeVar["net.minecraft.client.network.ClientPlayerEntity"]
World = TypeVar["net.minecraft.world.World"]
ItemStack = TypeVar["net.minecraft.item.ItemStack"]
Arm = TypeVar["net.minecraft.util.Arm"]
Vec3d = TypeVar["net.minecraft.util.math.Vec3d"]

class MovementDummy(LivingEntity):

	@overload
	def __init__(self, player: "MovementDummy") -> None:
		pass

	@overload
	def __init__(self, player: ClientPlayerEntity) -> None:
		pass

	@overload
	def __init__(self, world: World, pos: Vec3d, velocity: Vec3d, hitBox: Box, onGround: bool, isSprinting: bool, isSneaking: bool) -> None:
		pass

	@overload
	def getCoordsHistory(self) -> List[Vec3d]:
		pass

	@overload
	def getInputs(self) -> List[PlayerInput]:
		pass

	@overload
	def applyInput(self, input: PlayerInput) -> Vec3d:
		pass

	@overload
	def applyMovementInput(self, movementInput: Vec3d, f: float) -> Vec3d:
		"""We have to do this "inject" since the the applyClimbingSpeed() method
in LivingEntity is checking if we are a PlayerEntity, we want to apply the outcome of this check,
so this is why we need to set the y-velocity to 0.
		"""
		pass

	@overload
	def canMoveVoluntarily(self) -> bool:
		pass

	@overload
	def setSprinting(self, sprinting: bool) -> None:
		pass

	@overload
	def getMainHandStack(self) -> ItemStack:
		pass

	@overload
	def getArmorItems(self) -> Iterable:
		pass

	@overload
	def getEquippedStack(self, slot: EquipmentSlot) -> ItemStack:
		pass

	@overload
	def equipStack(self, slot: EquipmentSlot, stack: ItemStack) -> None:
		pass

	@overload
	def getMainArm(self) -> Arm:
		pass

	@overload
	def clone(self) -> "MovementDummy":
		pass

	pass





from typing import overload
from typing import List
from typing import TypeVar
from typing import Set

Prism4j_Grammar = TypeVar["io.noties.prism4j.Prism4j.Grammar"]
Prism4j_Node = TypeVar["io.noties.prism4j.Prism4j.Node"]
GrammarLocator = TypeVar["io.noties.prism4j.GrammarLocator"]

class Prism(GrammarLocator):

	@overload
	def __init__(self) -> None:
		pass

	@overload
	def getNodes(self, text: str, language: str) -> List[Prism4j_Node]:
		pass

	@overload
	def grammar(self, prism4j: Prism4j, language: str) -> Prism4j_Grammar:
		pass

	@overload
	def languages(self) -> Set[str]:
		pass

	pass


